"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import enum
import typing
import PyQt6.sip
from PyQt6.QtCore import *
import enum


class QThread(QObject):
    """
    https://doc.qt.io/qt-6/qthread.html

    **Detailed Description**

    A QThread object manages one thread of control within the program. QThreads
    begin executing in **run** (). By default, **run** () starts the event loop
    by calling **exec** () and runs a Qt event loop inside the thread.

    You can use worker objects by moving them to the thread using
    **QObject::moveToThread** ().

    class Worker : public **QObject**
        {
            Q_OBJECT

        public
    slots:
            void doWork(const **QString**  &parameter) {
    **QString**  result;
                /* ... here is the expensive or blocking
    operation ... */
                emit resultReady(result);
            }
    signals:
            void resultReady(const **QString**  &result);
        };
    class Controller : public **QObject**
        {
            Q_OBJECT
    **QThread**  workerThread;
        public:
            Controller() {
    Worker *worker = new Worker;
    worker->moveToThread(&workerThread);
                connect(&workerThread,
    &**QThread** ::finished, worker, &**QObject** ::deleteLater);
    connect(this, &Controller::operate, worker, &Worker::doWork);
    connect(worker, &Worker::resultReady, this, &Controller::handleResults);
    workerThread.start();
            }
            ~Controller() {
    workerThread.quit();
                workerThread.wait();
            }
        public
    slots:
            void handleResults(const **QString**  &);
        signals:
    void operate(const **QString**  &);
        };

    The code inside the Worker's slot would then execute in a separate thread.
    However, you are free to connect the Worker's slots to any signal, from any
    object, in any thread. It is safe to connect signals and slots across
    different threads, thanks to a mechanism called **queued connections** .

    Another way to make code run in a separate thread, is to subclass QThread
    and reimplement **run** (). For example:

    class WorkerThread : public **QThread**
        {
            Q_OBJECT
            void
    run() override {
                **QString**  result;
                /* ... here is
    the expensive or blocking operation ... */
                emit
    resultReady(result);
            }
        signals:
            void resultReady(const
    **QString**  &s);
        };

        void MyObject::startWorkInAThread()
        {
    WorkerThread *workerThread = new WorkerThread(this);
    connect(workerThread, &WorkerThread::resultReady, this,
    &MyObject::handleResults);
            connect(workerThread,
    &WorkerThread::finished, workerThread, &**QObject** ::deleteLater);
    workerThread->start();
        }

    In that example, the thread will exit after the run function has returned.
    There will not be any event loop running in the thread unless you call
    **exec** ().

    It is important to remember that a QThread instance **lives in**  the old
    thread that instantiated it, not in the new thread that calls **run** ().
    This means that all of QThread's queued slots and **invoked methods**  will
    execute in the old thread. Thus, a developer who wishes to invoke slots in
    the new thread must use the worker-object approach; new slots should not be
    implemented directly into a subclassed QThread.

    Unlike queued slots or invoked methods, methods called directly on the
    QThread object will execute in the thread that calls the method. When
    subclassing QThread, keep in mind that the constructor executes in the old
    thread while **run** () executes in the new thread. If a member variable is
    accessed from both functions, then the variable is accessed from two
    different threads. Check that it is safe to do so.

    **Note:** Care must be taken when interacting with objects across different
    threads. As a general rule, functions can only be called from the thread
    that created the QThread object itself (e.g. **setPriority** ()), unless the
    documentation says otherwise. See **Synchronizing Threads**  for details.

    **Managing Threads**

    QThread will notify you via a signal when the thread is **started** () and
    **finished** (), or you can use **isFinished** () and **isRunning** () to
    query the state of the thread.

    You can stop the thread by calling **exit** () or **quit** (). In extreme
    cases, you may want to forcibly **terminate** () an executing thread.
    However, doing so is dangerous and discouraged. Please read the
    documentation for **terminate** () and **setTerminationEnabled** () for
    detailed information.

    From Qt 4.8 onwards, it is possible to deallocate objects that live in a
    thread that has just ended, by connecting the **finished** () signal to
    **QObject::deleteLater** ().

    Use **wait** () to block the calling thread, until the other thread has
    finished execution (or until a specified time has passed).

    QThread also provides static, platform independent sleep functions:
    **sleep** (), **msleep** (), and **usleep** () allow full second,
    millisecond, and microsecond resolution respectively. These functions were
    made public in Qt 5.0.

    **Note:****wait** () and the **sleep** () functions should be unnecessary in
    general, since Qt is an event-driven framework. Instead of **wait** (),
    consider listening for the **finished** () signal. Instead of the **sleep**
    () functions, consider using **QTimer** .

    The static functions **currentThreadId** () and **currentThread** () return
    identifiers for the currently executing thread. The former returns a
    platform specific ID for the thread; the latter returns a QThread pointer.

    To choose the name that your thread will be given (as identified by the
    command `ps -L` on Linux, for example), you can call **setObjectName** ()
    before starting the thread. If you don't call **setObjectName** (), the name
    given to your thread will be the class name of the runtime type of your
    thread object (for example, `"RenderThread"` in the case of the **Mandelbrot
    Example** , as that is the name of the QThread subclass). Note that this is
    currently not available with release builds on Windows.

    **See also** **Thread Support in Qt** , **QThreadStorage** , **Synchronizing
    Threads** , **Mandelbrot Example** , **Semaphores Example** , and **Wait
    Conditions Example** .
    """

    class Priority(enum.Enum):
        IdlePriority: QThread = ...
        LowestPriority: QThread = ...
        LowPriority: QThread = ...
        NormalPriority: QThread = ...
        HighPriority: QThread = ...
        HighestPriority: QThread = ...
        TimeCriticalPriority: QThread = ...
        InheritPriority: QThread = ...

    def __init__(self, parent: typing.Optional[QObject] = ...) -> None:
        """
        https://doc.qt.io/qt-6/qthread.html#QThread

        **QThread::QThread(QObject * parent = nullptr)**

        Constructs a new QThread to manage a new thread. The **parent** takes
        ownership of the QThread. The thread does not begin executing until
        **start** () is called.

        **See also** **start** ().
        """
        ...

    def loopLevel(self) -> int:
        """
        https://doc.qt.io/qt-6/qthread.html#loopLevel

        **[since 5.5] int QThread::loopLevel() const**

        Returns the current event loop level for the thread.

        **Note:** This can only be called within the thread itself, i.e. when it
        is the current thread.

        This function was introduced in Qt 5.5.
        """
        ...

    def isInterruptionRequested(self) -> bool:
        """
        https://doc.qt.io/qt-6/qthread.html#isInterruptionRequested

        **[since 5.2] bool QThread::isInterruptionRequested() const**

        Return true if the task running on this thread should be stopped. An
        interruption can be requested by **requestInterruption** ().

        This function can be used to make long running tasks cleanly
        interruptible. Never checking or acting on the value returned by this
        function is safe, however it is advisable do so regularly in long
        running functions. Take care not to call it too often, to keep the
        overhead low.

        void long_task() {
                 forever {
                    if ( **QThread**
        ::currentThread()->isInterruptionRequested() ) {
                        return;
        }
                }
            }

        **Note:** This can only be called within the thread itself, i.e. when it
        is the current thread.

        This function was introduced in Qt 5.2.

        **See also** **currentThread** () and **requestInterruption** ().
        """
        ...

    def requestInterruption(self) -> None:
        """
        https://doc.qt.io/qt-6/qthread.html#requestInterruption

        **[since 5.2] void QThread::requestInterruption()**

        Request the interruption of the thread. That request is advisory and it
        is up to code running on the thread to decide if and how it should act
        upon such request. This function does not stop any event loop running on
        the thread and does not terminate it in any way.

        **Note:** This function is **thread-safe** .

        This function was introduced in Qt 5.2.

        **See also** **isInterruptionRequested** ().
        """
        ...

    def setEventDispatcher(self, eventDispatcher: QAbstractEventDispatcher) -> None:
        """
        https://doc.qt.io/qt-6/qthread.html#setEventDispatcher

        **[since 5.0] void QThread::setEventDispatcher(QAbstractEventDispatcher
        * eventDispatcher )**

        Sets the event dispatcher for the thread to **eventDispatcher**. This is
        only possible as long as there is no event dispatcher installed for the
        thread yet. That is, before the thread has been started with **start**
        () or, in case of the main thread, before **QCoreApplication**  has been
        instantiated. This method takes ownership of the object.

        This function was introduced in Qt 5.0.

        **See also** **eventDispatcher** ().
        """
        ...

    def eventDispatcher(self) -> QAbstractEventDispatcher:
        """
        https://doc.qt.io/qt-6/qthread.html#eventDispatcher

        **[since 5.0] QAbstractEventDispatcher *QThread::eventDispatcher()
        const**

        Returns a pointer to the event dispatcher object for the thread. If no
        event dispatcher exists for the thread, this function returns `nullptr`.

        This function was introduced in Qt 5.0.

        **See also** **setEventDispatcher** ().
        """
        ...

    @staticmethod
    def usleep(a0: int) -> None:
        """
        https://doc.qt.io/qt-6/qthread.html#usleep

        **[static] void QThread::usleep(unsigned long usecs )**

        Forces the current thread to sleep for **usecs** microseconds.

        Avoid using this function if you need to wait for a given condition to
        change. Instead, connect a slot to the signal that indicates the change
        or use an event handler (see **QObject::event** ()).

        **Note:** This function does not guarantee accuracy. The application may
        sleep longer than **usecs** under heavy load conditions. Some OSes might
        round **usecs** up to 10 ms or 15 ms; on Windows, it will be rounded up
        to a multiple of 1 ms.

        **See also** **sleep** () and **msleep** ().
        """
        ...

    @staticmethod
    def msleep(a0: int) -> None:
        """
        https://doc.qt.io/qt-6/qthread.html#msleep

        **[static] void QThread::msleep(unsigned long msecs )**

        Forces the current thread to sleep for **msecs** milliseconds.

        Avoid using this function if you need to wait for a given condition to
        change. Instead, connect a slot to the signal that indicates the change
        or use an event handler (see **QObject::event** ()).

        **Note:** This function does not guarantee accuracy. The application may
        sleep longer than **msecs** under heavy load conditions. Some OSes might
        round **msecs** up to 10 ms or 15 ms.

        **See also** **sleep** () and **usleep** ().
        """
        ...

    @staticmethod
    def sleep(a0: int) -> None:
        """
        https://doc.qt.io/qt-6/qthread.html#sleep

        **[static] void QThread::sleep(unsigned long secs )**

        Forces the current thread to sleep for **secs** seconds.

        Avoid using this function if you need to wait for a given condition to
        change. Instead, connect a slot to the signal that indicates the change
        or use an event handler (see **QObject::event** ()).

        **Note:** This function does not guarantee accuracy. The application may
        sleep longer than **secs** under heavy load conditions.

        **See also** **msleep** () and **usleep** ().
        """
        ...

    def event(self, event: QEvent) -> bool:
        """
        https://doc.qt.io/qt-6/qthread.html#event

        **[override virtual] bool QThread::event(QEvent * event )**

        Reimplements: **QObject::event** (QEvent *e).
        """
        ...

    @staticmethod
    def setTerminationEnabled(enabled: bool = ...) -> None:
        """
        https://doc.qt.io/qt-6/qthread.html#setTerminationEnabled

        **[static protected] void QThread::setTerminationEnabled(bool enabled =
        true)**

        Enables or disables termination of the current thread based on the
        **enabled** parameter. The thread must have been started by **QThread**
        .

        When **enabled** is false, termination is disabled. Future calls to
        **QThread::terminate** () will return immediately without effect.
        Instead, the termination is deferred until termination is enabled.

        When **enabled** is true, termination is enabled. Future calls to
        **QThread::terminate** () will terminate the thread normally. If
        termination has been deferred (i.e. **QThread::terminate** () was called
        with termination disabled), this function will terminate the calling
        thread **immediately**. Note that this function will not return in this
        case.

        **See also** **terminate** ().
        """
        ...

    def exec(self) -> int:
        """
        https://doc.qt.io/qt-6/qthread.html#exec

        **[protected] int QThread::exec()**

        Enters the event loop and waits until **exit** () is called, returning
        the value that was passed to **exit** (). The value returned is 0 if
        **exit** () is called via **quit** ().

        This function is meant to be called from within **run** (). It is
        necessary to call this function to start event handling.

        **Note:** This can only be called within the thread itself, i.e. when it
        is the current thread.

        **See also** **quit** () and **exit** ().
        """
        ...

    def run(self) -> None:
        """
        https://doc.qt.io/qt-6/qthread.html#run

        **[virtual protected] void QThread::run()**

        The starting point for the thread. After calling **start** (), the newly
        created thread calls this function. The default implementation simply
        calls **exec** ().

        You can reimplement this function to facilitate advanced thread
        management. Returning from this method will end the execution of the
        thread.

        **See also** **start** () and **wait** ().
        """
        ...

    @typing.overload
    def wait(self, deadline: QDeadlineTimer = ...) -> bool:
        """
        https://doc.qt.io/qt-6/qthread.html#wait

        **[since 5.15] bool QThread::wait(QDeadlineTimer deadline =
        QDeadlineTimer(QDeadlineTimer::Forever))**

        Blocks the thread until either of these conditions is met:

        * The thread associated with this **QThread**  object has finished
        execution (i.e. when it returns from **run** ()). This function will
        return true if the thread has finished. It also returns true if the
        thread has not been started yet.
          * The **deadline** is reached. This
        function will return false if the deadline is reached.

        A deadline timer set to `QDeadlineTimer::Forever` (the default) will
        never time out: in this case, the function only returns when the thread
        returns from **run** () or if the thread has not yet started.

        This provides similar functionality to the POSIX `pthread_join()`
        function.

        This function was introduced in Qt 5.15.

        **See also** **sleep** () and **terminate** ().
        """
        ...

    @typing.overload
    def wait(self, time: int) -> bool:
        """
        https://doc.qt.io/qt-6/qthread.html#wait-1

        **bool QThread::wait(unsigned long time )**

        This is an overloaded function.

        **time** is the time to wait in milliseconds. If **time** is ULONG_MAX,
        then the wait will never timeout.
        """
        ...

    def quit(self) -> None:
        """
        https://doc.qt.io/qt-6/qthread.html#quit

        **[slot] void QThread::quit()**

        Tells the thread's event loop to exit with return code 0 (success).
        Equivalent to calling **QThread::exit** (0).

        This function does nothing if the thread does not have an event loop.

        **Note:** This function is **thread-safe** .

        **See also** **exit** () and **QEventLoop** .
        """
        ...

    def terminate(self) -> None:
        """
        https://doc.qt.io/qt-6/qthread.html#terminate

        **[slot] void QThread::terminate()**

        Terminates the execution of the thread. The thread may or may not be
        terminated immediately, depending on the operating system's scheduling
        policies. Use **QThread::wait** () after terminate(), to be sure.

        When the thread is terminated, all threads waiting for the thread to
        finish will be woken up.

        **Warning:** This function is dangerous and its use is discouraged. The
        thread can be terminated at any point in its code path. Threads can be
        terminated while modifying data. There is no chance for the thread to
        clean up after itself, unlock any held mutexes, etc. In short, use this
        function only if absolutely necessary.

        Termination can be explicitly enabled or disabled by calling
        **QThread::setTerminationEnabled** (). Calling this function while
        termination is disabled results in the termination being deferred, until
        termination is re-enabled. See the documentation of
        **QThread::setTerminationEnabled** () for more information.

        **Note:** This function is **thread-safe** .

        **See also** **setTerminationEnabled** ().
        """
        ...

    def start(self, priority: "QThread.Priority" = ...) -> None:
        """
        https://doc.qt.io/qt-6/qthread.html#start

        **[slot] void QThread::start(QThread::Priority priority =
        InheritPriority)**

        Begins execution of the thread by calling **run** (). The operating
        system will schedule the thread according to the **priority** parameter.
        If the thread is already running, this function does nothing.

        The effect of the **priority** parameter is dependent on the operating
        system's scheduling policy. In particular, the **priority** will be
        ignored on systems that do not support thread priorities (such as on
        Linux, see the **sched_setscheduler**  documentation for more details).

        **See also** **run** () and **terminate** ().
        """
        ...

    def exit(self, returnCode: int = ...) -> None:
        """
        https://doc.qt.io/qt-6/qthread.html#exit

        **[slot] void QThread::exit(int returnCode = 0)**

        Tells the thread's event loop to exit with a return code.

        After calling this function, the thread leaves the event loop and
        returns from the call to **QEventLoop::exec** (). The
        **QEventLoop::exec** () function returns **returnCode**.

        By convention, a **returnCode** of 0 means success, any non-zero value
        indicates an error.

        Note that unlike the C library function of the same name, this function
        **does** return to the caller -- it is event processing that stops.

        No QEventLoops will be started anymore in this thread until
        **QThread::exec** () has been called again. If the eventloop in
        **QThread::exec** () is not running then the next call to
        **QThread::exec** () will also return immediately.

        **Note:** This function is **thread-safe** .

        **See also** **quit** () and **QEventLoop** .
        """
        ...

    def stackSize(self) -> int:
        """
        https://doc.qt.io/qt-6/qthread.html#stackSize

        **uint QThread::stackSize() const**

        Returns the maximum stack size for the thread (if set with
        **setStackSize** ()); otherwise returns zero.

        **See also** **setStackSize** ().
        """
        ...

    def setStackSize(self, stackSize: int) -> None:
        """
        https://doc.qt.io/qt-6/qthread.html#setStackSize

        **void QThread::setStackSize(uint stackSize )**

        Sets the maximum stack size for the thread to **stackSize**. If
        **stackSize** is greater than zero, the maximum stack size is set to
        **stackSize** bytes, otherwise the maximum stack size is automatically
        determined by the operating system.

        **Warning:** Most operating systems place minimum and maximum limits on
        thread stack sizes. The thread will fail to start if the stack size is
        outside these limits.

        **See also** **stackSize** ().
        """
        ...

    def priority(self) -> "QThread.Priority":
        """
        https://doc.qt.io/qt-6/qthread.html#priority

        **QThread::Priority QThread::priority() const**

        Returns the priority for a running thread. If the thread is not running,
        this function returns `InheritPriority`.

        **See also** **Priority** , **setPriority** (), and **start** ().
        """
        ...

    def setPriority(self, priority: "QThread.Priority") -> None:
        """
        https://doc.qt.io/qt-6/qthread.html#setPriority

        **void QThread::setPriority(QThread::Priority priority )**

        This function sets the **priority** for a running thread. If the thread
        is not running, this function does nothing and returns immediately. Use
        **start** () to start a thread with a specific priority.

        The **priority** argument can be any value in the `QThread::Priority`
        enum except for `InheritPriority`.

        The effect of the **priority** parameter is dependent on the operating
        system's scheduling policy. In particular, the **priority** will be
        ignored on systems that do not support thread priorities (such as on
        Linux, see http://linux.die.net/man/2/sched_setscheduler for more
        details).

        **See also** **Priority** , **priority** (), and **start** ().
        """
        ...

    def isRunning(self) -> bool:
        """
        https://doc.qt.io/qt-6/qthread.html#isRunning

        **bool QThread::isRunning() const**

        Returns `true` if the thread is running; otherwise returns `false`.

        **Note:** This function is **thread-safe** .

        **See also** **isFinished** ().
        """
        ...

    def isFinished(self) -> bool:
        """
        https://doc.qt.io/qt-6/qthread.html#isFinished

        **bool QThread::isFinished() const**

        Returns `true` if the thread is finished; otherwise returns `false`.

        **Note:** This function is **thread-safe** .

        **See also** **isRunning** ().
        """
        ...

    @staticmethod
    def yieldCurrentThread() -> None:
        """
        https://doc.qt.io/qt-6/qthread.html#yieldCurrentThread

        **[static] void QThread::yieldCurrentThread()**

        Yields execution of the current thread to another runnable thread, if
        any. Note that the operating system decides to which thread to switch.
        """
        ...

    @staticmethod
    def idealThreadCount() -> int:
        """
        https://doc.qt.io/qt-6/qthread.html#idealThreadCount

        **[static] int QThread::idealThreadCount()**

        Returns the ideal number of threads that can be run on the system. This
        is done querying the number of processor cores, both real and logical,
        in the system. This function returns 1 if the number of processor cores
        could not be detected.
        """
        ...

    @staticmethod
    def currentThreadId() -> PyQt6.sip.voidptr:
        """
        https://doc.qt.io/qt-6/qthread.html#currentThreadId

        **[static] Qt::HANDLE QThread::currentThreadId()**

        Returns the thread handle of the currently executing thread.

        **Warning:** The handle returned by this function is used for internal
        purposes and should not be used in any application code.

        **Note:** On Windows, this function returns the DWORD (Windows-Thread
        ID) returned by the Win32 function GetCurrentThreadId(), not the pseudo-
        HANDLE (Windows-Thread HANDLE) returned by the Win32 function
        GetCurrentThread().
        """
        ...

    @staticmethod
    def currentThread() -> "QThread":
        """
        https://doc.qt.io/qt-6/qthread.html#currentThread

        **[static] QThread *QThread::currentThread()**

        Returns a pointer to a **QThread**  which manages the currently
        executing thread.
        """
        ...

    @property
    def finished(self) -> PyQt6.QtCore.pyqtBoundSignal:
        """
        https://doc.qt.io/qt-6/qthread.html#finished

        **[private signal] void QThread::finished()**

        This signal is emitted from the associated thread right before it
        finishes executing.

        When this signal is emitted, the event loop has already stopped running.
        No more events will be processed in the thread, except for deferred
        deletion events. This signal can be connected to
        **QObject::deleteLater** (), to free objects in that thread.

        **Note:** If the associated thread was terminated using **terminate**
        (), it is undefined from which thread this signal is emitted.

        **Note:** This is a private signal. It can be used in signal connections
        but cannot be emitted by the user.

        **See also** **started** ().
        """
        ...

    @property
    def started(self) -> PyQt6.QtCore.pyqtBoundSignal:
        """
        https://doc.qt.io/qt-6/qthread.html#started

        **[private signal] void QThread::started()**

        This signal is emitted from the associated thread when it starts
        executing, before the **run** () function is called.

        **Note:** This is a private signal. It can be used in signal connections
        but cannot be emitted by the user.

        **See also** **finished** ().
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import enum
import typing
import PyQt6.sip
from PyQt6.QtCore import *
import enum


class QCommandLineOption(PyQt6.sip.simplewrapper):
    """
    https://doc.qt.io/qt-6/qcommandlineoption.html

    **Detailed Description**

    This class is used to describe an option on the command line. It allows
    different ways of defining the same option with multiple aliases possible.
    It is also used to describe how the option is used - it may be a flag (e.g.
    `-v`) or take a value (e.g. `-o file`).

    Examples:

    **QCommandLineOption**  verboseOption("verbose", "Verbose mode. Prints out
    more information.");
        **QCommandLineOption**
    outputOption(**QStringList** () << "o" << "output", "Write generated data
    into <file>.", "file");

    **See also** **QCommandLineParser** .
    """

    class Flag(enum.Flag):
        HiddenFromHelp: QCommandLineOption = ...
        ShortOptionStyle: QCommandLineOption = ...

    @typing.overload
    def __init__(self, name: str) -> None:
        """
        https://doc.qt.io/qt-6/qcommandlineoption.html#QCommandLineOption

        **QCommandLineOption::QCommandLineOption(const QString & name )**

        Constructs a command line option object with the name **name**.

        The name can be either short or long. If the name is one character in
        length, it is considered a short name. Option names must not be empty,
        must not start with a dash or a slash character, must not contain a `=`
        and cannot be repeated.

        **See also** **setDescription** (), **setValueName** (), and
        **setDefaultValues** ().
        """
        ...

    @typing.overload
    def __init__(self, names: typing.Iterable[str]) -> None:
        """
        https://doc.qt.io/qt-6/qcommandlineoption.html#QCommandLineOption-1

        **QCommandLineOption::QCommandLineOption(const QStringList & names )**

        Constructs a command line option object with the names **names**.

        This overload allows to set multiple names for the option, for instance
        `o` and `output`.

        The names can be either short or long. Any name in the list that is one
        character in length is a short name. Option names must not be empty,
        must not start with a dash or a slash character, must not contain a `=`
        and cannot be repeated.

        **See also** **setDescription** (), **setValueName** (), and
        **setDefaultValues** ().
        """
        ...

    @typing.overload
    def __init__(
        self, name: str, description: str, valueName: str = ..., defaultValue: str = ...
    ) -> None:
        """
        https://doc.qt.io/qt-6/qcommandlineoption.html#QCommandLineOption-2

        **QCommandLineOption::QCommandLineOption(const QString & name , const
        QString & description , const QString & valueName = QString(), const
        QString & defaultValue = QString())**

        Constructs a command line option object with the given arguments.

        The name of the option is set to **name**. The name can be either short
        or long. If the name is one character in length, it is considered a
        short name. Option names must not be empty, must not start with a dash
        or a slash character, must not contain a `=` and cannot be repeated.

        The description is set to **description**. It is customary to add a "."
        at the end of the description.

        In addition, the **valueName** needs to be set if the option expects a
        value. The default value for the option is set to **defaultValue**.

        In Qt versions before 5.4, this constructor was `explicit`. In Qt 5.4
        and later, it no longer is and can be used for C++11-style uniform
        initialization:

        **QCommandLineParser**  parser;
            parser.addOption({"verbose",
        "Verbose mode. Prints out more information."});

        **See also** **setDescription** (), **setValueName** (), and
        **setDefaultValues** ().
        """
        ...

    @typing.overload
    def __init__(
        self,
        names: typing.Iterable[str],
        description: str,
        valueName: str = ...,
        defaultValue: str = ...,
    ) -> None:
        """
        https://doc.qt.io/qt-6/qcommandlineoption.html#QCommandLineOption-3

        **QCommandLineOption::QCommandLineOption(const QStringList & names ,
        const QString & description , const QString & valueName = QString(),
        const QString & defaultValue = QString())**

        Constructs a command line option object with the given arguments.

        This overload allows to set multiple names for the option, for instance
        `o` and `output`.

        The names of the option are set to **names**. The names can be either
        short or long. Any name in the list that is one character in length is a
        short name. Option names must not be empty, must not start with a dash
        or a slash character, must not contain a `=` and cannot be repeated.

        The description is set to **description**. It is customary to add a "."
        at the end of the description.

        In addition, the **valueName** needs to be set if the option expects a
        value. The default value for the option is set to **defaultValue**.

        In Qt versions before 5.4, this constructor was `explicit`. In Qt 5.4
        and later, it no longer is and can be used for C++11-style uniform
        initialization:

        **QCommandLineParser**  parser;
            parser.addOption({{"o", "output"},
        "Write generated data into <file>.", "file"});

        **See also** **setDescription** (), **setValueName** (), and
        **setDefaultValues** ().
        """
        ...

    @typing.overload
    def __init__(self, other: "QCommandLineOption") -> None:
        """
        https://doc.qt.io/qt-6/qcommandlineoption.html#QCommandLineOption-4

        **QCommandLineOption::QCommandLineOption(const QCommandLineOption &
        other )**

        Constructs a QCommandLineOption object that is a copy of the
        QCommandLineOption object **other**.

        **See also** **operator=** ().
        """
        ...

    def setFlags(self, aflags: "QCommandLineOption.Flag") -> None:
        """
        https://doc.qt.io/qt-6/qcommandlineoption.html#setFlags

        **[since 5.8] void
        QCommandLineOption::setFlags(QCommandLineOption::Flags flags )**

        Set the set of flags that affect this command-line option to **flags**.

        This function was introduced in Qt 5.8.

        **See also** **flags** () and **QCommandLineOption::Flags** .
        """
        ...

    def flags(self) -> "QCommandLineOption.Flag":
        """
        https://doc.qt.io/qt-6/qcommandlineoption.html#flags

        **[since 5.8] QCommandLineOption::Flags QCommandLineOption::flags()
        const**

        Returns a set of flags that affect this command-line option.

        This function was introduced in Qt 5.8.

        **See also** **setFlags** () and **QCommandLineOption::Flags** .
        """
        ...

    def defaultValues(self) -> typing.List[str]:
        """
        https://doc.qt.io/qt-6/qcommandlineoption.html#defaultValues

        **QStringList QCommandLineOption::defaultValues() const**

        Returns the default values set for this option.

        **See also** **setDefaultValues** ().
        """
        ...

    def setDefaultValues(self, defaultValues: typing.Iterable[str]) -> None:
        """
        https://doc.qt.io/qt-6/qcommandlineoption.html#setDefaultValues

        **void QCommandLineOption::setDefaultValues(const QStringList &
        defaultValues )**

        Sets the list of default values used for this option to
        **defaultValues**.

        The default values are used if the user of the application does not
        specify the option on the command line.

        **See also** **defaultValues** () and **setDefaultValue** ().
        """
        ...

    def setDefaultValue(self, defaultValue: str) -> None:
        """
        https://doc.qt.io/qt-6/qcommandlineoption.html#setDefaultValue

        **void QCommandLineOption::setDefaultValue(const QString & defaultValue
        )**

        Sets the default value used for this option to **defaultValue**.

        The default value is used if the user of the application does not
        specify the option on the command line.

        If **defaultValue** is empty, the option has no default values.

        **See also** **defaultValues** () and **setDefaultValues** ().
        """
        ...

    def description(self) -> str:
        """
        https://doc.qt.io/qt-6/qcommandlineoption.html#description

        **QString QCommandLineOption::description() const**

        Returns the description set for this option.

        **See also** **setDescription** ().
        """
        ...

    def setDescription(self, description: str) -> None:
        """
        https://doc.qt.io/qt-6/qcommandlineoption.html#setDescription

        **void QCommandLineOption::setDescription(const QString & description
        )**

        Sets the description used for this option to **description**.

        It is customary to add a "." at the end of the description.

        The description is used by **QCommandLineParser::showHelp** ().

        **See also** **description** ().
        """
        ...

    def valueName(self) -> str:
        """
        https://doc.qt.io/qt-6/qcommandlineoption.html#valueName

        **QString QCommandLineOption::valueName() const**

        Returns the name of the expected value.

        If empty, the option doesn't take a value.

        **See also** **setValueName** ().
        """
        ...

    def setValueName(self, name: str) -> None:
        """
        https://doc.qt.io/qt-6/qcommandlineoption.html#setValueName

        **void QCommandLineOption::setValueName(const QString & valueName )**

        Sets the name of the expected value, for the documentation, to
        **valueName**.

        Options without a value assigned have a boolean-like behavior: either
        the user specifies --option or they don't.

        Options with a value assigned need to set a name for the expected value,
        for the documentation of the option in the help output. An option with
        names `o` and `output`, and a value name of `file` will appear as `-o,
        --output <file>`.

        Call **QCommandLineParser::value** () if you expect the option to be
        present only once, and **QCommandLineParser::values** () if you expect
        that option to be present multiple times.

        **See also** **valueName** ().
        """
        ...

    def names(self) -> typing.List[str]:
        """
        https://doc.qt.io/qt-6/qcommandlineoption.html#names

        **QStringList QCommandLineOption::names() const**

        Returns the names set for this option.
        """
        ...

    def swap(self, other: "QCommandLineOption") -> None:
        """
        https://doc.qt.io/qt-6/qcommandlineoption.html#swap

        **void QCommandLineOption::swap(QCommandLineOption & other )**

        Swaps option **other** with this option. This operation is very fast and
        never fails.
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import enum
import typing
import PyQt6.sip
from PyQt6.QtHelp import *
import enum


class QHelpSearchQuery(PyQt6.sip.simplewrapper):
    """
    https://doc.qt.io/qt-6/qhelpsearchquery.html

    **Detailed Description**

    The QHelpSearchQuery class contains the field name and the associated search
    term. Depending on the field the search term might get split up into
    separate terms to be parsed differently by the search engine.

    **Note:** This class has been deprecated in favor of **QString** .

    **See also** **QHelpSearchQueryWidget** .
    """

    class FieldName(enum.Enum):
        DEFAULT: QHelpSearchQuery = ...
        FUZZY: QHelpSearchQuery = ...
        WITHOUT: QHelpSearchQuery = ...
        PHRASE: QHelpSearchQuery = ...
        ALL: QHelpSearchQuery = ...
        ATLEAST: QHelpSearchQuery = ...

    @typing.overload
    def __init__(self) -> None:
        """
        https://doc.qt.io/qt-6/qhelpsearchquery.html#QHelpSearchQuery

        **QHelpSearchQuery::QHelpSearchQuery()**

        Constructs a new empty QHelpSearchQuery.
        """
        ...

    @typing.overload
    def __init__(
        self, field: "QHelpSearchQuery.FieldName", wordList: typing.Iterable[str]
    ) -> None:
        """
        https://doc.qt.io/qt-6/qhelpsearchquery.html#QHelpSearchQuery-1

        **QHelpSearchQuery::QHelpSearchQuery(QHelpSearchQuery::FieldName field ,
        const QStringList & wordList )**

        Constructs a new QHelpSearchQuery and initializes it with the given
        **field** and **wordList**.
        """
        ...

    @typing.overload
    def __init__(self, a0: "QHelpSearchQuery") -> None:
        """
        https://doc.qt.io/qt-6/qhelpsearchquery.html#QHelpSearchQuery

        **QHelpSearchQuery::QHelpSearchQuery()**

        Constructs a new empty QHelpSearchQuery.
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import enum
import typing
import PyQt6.sip
from PyQt6 import QtCore
from PyQt6.QtPositioning import *
import enum


class QGeoPositionInfoSource(QtCore.QObject):
    """
    https://doc.qt.io/qt-6/qgeopositioninfosource.html

    **Detailed Description**

    The static function **QGeoPositionInfoSource::createDefaultSource** ()
    creates a default position source that is appropriate for the platform, if
    one is available. Otherwise, QGeoPositionInfoSource will check for available
    plugins that implement the **QGeoPositionInfoSourceFactory**  interface.

    Users of a QGeoPositionInfoSource subclass can request the current position
    using **requestUpdate** (), or start and stop regular position updates using
    **startUpdates** () and **stopUpdates** (). When an update is available,
    **positionUpdated** () is emitted. The last known position can be accessed
    with **lastKnownPosition** ().

    If regular position updates are required, **setUpdateInterval** () can be
    used to specify how often these updates should be emitted. If no interval is
    specified, updates are simply provided whenever they are available. For
    example:

    // Emit updates every 10 seconds if available
        **QGeoPositionInfoSource**
    *source = **QGeoPositionInfoSource** ::createDefaultSource(0);
        if
    (source)
            source->setUpdateInterval(10000);

    To remove an update interval that was previously set, call
    **setUpdateInterval** () with a value of 0.

    **Note:** The position source may have a minimum value requirement for
    update intervals, as returned by **minimumUpdateInterval** ().

    **Note:** To use this class from Android service, see **Qt Positioning on
    Android** .
    """

    class PositioningMethod(enum.Flag):
        NoPositioningMethods: QGeoPositionInfoSource = ...
        SatellitePositioningMethods: QGeoPositionInfoSource = ...
        NonSatellitePositioningMethods: QGeoPositionInfoSource = ...
        AllPositioningMethods: QGeoPositionInfoSource = ...

    class Error(enum.Enum):
        AccessError: QGeoPositionInfoSource = ...
        ClosedError: QGeoPositionInfoSource = ...
        UnknownSourceError: QGeoPositionInfoSource = ...
        UpdateTimeoutError: QGeoPositionInfoSource = ...
        NoError: QGeoPositionInfoSource = ...

    def __init__(self, parent: QtCore.QObject) -> None:
        """
        https://doc.qt.io/qt-6/qgeopositioninfosource.html#QGeoPositionInfoSourc
        e

        **QGeoPositionInfoSource::QGeoPositionInfoSource(QObject * parent )**

        Creates a position source with the specified **parent**.
        """
        ...

    def backendProperty(self, name: str) -> typing.Any:
        """
        https://doc.qt.io/qt-6/qgeopositioninfosource.html#backendProperty

        **[virtual, since Qt 5.14] QVariant
        QGeoPositionInfoSource::backendProperty(const QString & name ) const**

        Returns the value of the backend-specific property named **name** , if
        present. Otherwise, the returned value will be invalid. Supported
        backend-specific properties are listed and described in **Qt Positioning
        plugins#Default plugins** .

        This function was introduced in Qt 5.14.

        **See also** **setBackendProperty** .
        """
        ...

    def setBackendProperty(self, name: str, value: typing.Any) -> bool:
        """
        https://doc.qt.io/qt-6/qgeopositioninfosource.html#setBackendProperty

        **[virtual, since Qt 5.14] bool
        QGeoPositionInfoSource::setBackendProperty(const QString & name , const
        QVariant & value )**

        Sets the backend-specific property named **name** to **value**. Returns
        `true` on success, `false` otherwise. Backend-specific properties can be
        used to configure the positioning subsystem behavior at runtime.
        Supported backend-specific properties are listed and described in **Qt
        Positioning plugins#Default plugins** .

        This function was introduced in Qt 5.14.

        **See also** **backendProperty** .
        """
        ...

    def requestUpdate(self, timeout: int = ...) -> None:
        """
        https://doc.qt.io/qt-6/qgeopositioninfosource.html#requestUpdate

        **[pure virtual slot] void QGeoPositionInfoSource::requestUpdate(int
        timeout = 0)**

        Attempts to get the current position and emit **positionUpdated** ()
        with this information. If the current position cannot be found within
        the given **timeout** (in milliseconds) or if **timeout** is less than
        the value returned by **minimumUpdateInterval** (), an **errorOccurred**
        () signal with the **UpdateTimeoutError**  is emitted.

        If the timeout is zero, the timeout defaults to a reasonable timeout
        period as appropriate for the source.

        This does nothing if another update request is in progress. However it
        can be called even if **startUpdates** () has already been called and
        regular updates are in progress.

        If the source uses multiple positioning methods, it tries to get the
        current position from the most accurate positioning method within the
        given timeout.

        **Note:** Since Qt6 this method always resets the last error to
        **NoError**  before requesting the position.

        **Note:** To understand how to use this method from an Android service,
        see **Qt Positioning on Android** .
        """
        ...

    def stopUpdates(self) -> None:
        """
        https://doc.qt.io/qt-6/qgeopositioninfosource.html#stopUpdates

        **[pure virtual slot] void QGeoPositionInfoSource::stopUpdates()**

        Stops emitting updates at regular intervals.
        """
        ...

    def startUpdates(self) -> None:
        """
        https://doc.qt.io/qt-6/qgeopositioninfosource.html#startUpdates

        **[pure virtual slot] void QGeoPositionInfoSource::startUpdates()**

        Starts emitting updates at regular intervals as specified by
        **setUpdateInterval** ().

        If **setUpdateInterval** () has not been called, the source will emit
        updates as soon as they become available.

        An **errorOccurred** () signal with the **UpdateTimeoutError**  will be
        emitted if this **QGeoPositionInfoSource**  subclass determines that it
        will not be able to provide regular updates. This could happen if a
        satellite fix is lost or if a hardware error is detected. Position
        updates will recommence if the data becomes available later on. The
        **UpdateTimeoutError**  error will not be emitted again until after the
        periodic updates resume.

        **Note:** Since Qt6 this method always resets the last error to
        **NoError**  before starting the updates.

        **Note:** To understand how to use this method from an Android service,
        see **Qt Positioning on Android** .

        On iOS, starting from version 8, Core Location framework requires
        additional entries in the application's Info.plist with keys
        NSLocationAlwaysUsageDescription or NSLocationWhenInUseUsageDescription
        and a string to be displayed in the authorization prompt. The key
        NSLocationWhenInUseUsageDescription is used when requesting permission
        to use location services while the app is in the foreground. The key
        NSLocationAlwaysUsageDescription is used when requesting permission to
        use location services whenever the app is running (both the foreground
        and the background). If both entries are defined,
        NSLocationWhenInUseUsageDescription has a priority in the foreground
        mode.
        """
        ...

    def error(self) -> "QGeoPositionInfoSource.Error":
        """
        https://doc.qt.io/qt-6/qgeopositioninfosource.html#error

        **[pure virtual] QGeoPositionInfoSource::Error
        QGeoPositionInfoSource::error() const**

        Returns the type of error that last occurred.

        **Note:** Since Qt6 the last error is always reset when calling
        **startUpdates** () or **requestUpdate** ().
        """
        ...

    @staticmethod
    def availableSources() -> typing.List[str]:
        """
        https://doc.qt.io/qt-6/qgeopositioninfosource.html#availableSources

        **[static] QStringList QGeoPositionInfoSource::availableSources()**

        Returns a list of available source plugins. This includes any default
        backend plugin for the current platform.
        """
        ...

    @typing.overload
    @staticmethod
    def createSource(
        sourceName: str, parent: QtCore.QObject
    ) -> "QGeoPositionInfoSource":
        """
        https://doc.qt.io/qt-6/qgeopositioninfosource.html#createSource

        **[static] QGeoPositionInfoSource
        *QGeoPositionInfoSource::createSource(const QString & sourceName ,
        QObject * parent )**

        Creates and returns a position source with the given **parent** , by
        loading the plugin named **sourceName**.

        Returns `nullptr` if the plugin cannot be found.
        """
        ...

    @typing.overload
    @staticmethod
    def createSource(
        sourceName: str,
        parameters: typing.Dict[str, typing.Any],
        parent: QtCore.QObject,
    ) -> "QGeoPositionInfoSource":
        """
        https://doc.qt.io/qt-6/qgeopositioninfosource.html#createSource-1

        **[static, since Qt 5.14] QGeoPositionInfoSource
        *QGeoPositionInfoSource::createSource(const QString & sourceName , const
        QVariantMap & parameters , QObject * parent )**

        Creates and returns a position source with the given **parent** , by
        loading the plugin named **sourceName**.

        Returns `nullptr` if the plugin cannot be found.

        This method passes **parameters** to the factory to configure the
        source.

        This function was introduced in Qt 5.14.
        """
        ...

    @typing.overload
    @staticmethod
    def createDefaultSource(parent: QtCore.QObject) -> "QGeoPositionInfoSource":
        """
        https://doc.qt.io/qt-6/qgeopositioninfosource.html#createDefaultSource

        **[static] QGeoPositionInfoSource
        *QGeoPositionInfoSource::createDefaultSource(QObject * parent )**

        Creates and returns a position source with the given **parent** that
        reads from the system's default sources of location data, or the plugin
        with the highest available priority.

        Returns `nullptr` if the system has no default position source, no valid
        plugins could be found or the user does not have the permission to
        access the current position.
        """
        ...

    @typing.overload
    @staticmethod
    def createDefaultSource(
        parameters: typing.Dict[str, typing.Any], parent: QtCore.QObject
    ) -> "QGeoPositionInfoSource":
        """
        https://doc.qt.io/qt-6/qgeopositioninfosource.html#createDefaultSource-1

        **[static, since Qt 5.14] QGeoPositionInfoSource
        *QGeoPositionInfoSource::createDefaultSource(const QVariantMap &
        parameters , QObject * parent )**

        Creates and returns a position source with the given **parent** that
        reads from the system's default sources of location data, or the plugin
        with the highest available priority.

        Returns `nullptr` if the system has no default position source, no valid
        plugins could be found or the user does not have the permission to
        access the current position.

        This method passes **parameters** to the factory to configure the
        source.

        This function was introduced in Qt 5.14.
        """
        ...

    def sourceName(self) -> str:
        """
        https://doc.qt.io/qt-6/qgeopositioninfosource.html#sourceName-prop

        **[read-only] sourceName : const QString**

        This property holds the unique name of the position source
        implementation in use.

        This is the same name that can be passed to **createSource** () in order
        to create a new instance of a particular position source implementation.

        **Access functions:**

        QString **sourceName** () const
        """
        ...

    def minimumUpdateInterval(self) -> int:
        """
        https://doc.qt.io/qt-6/qgeopositioninfosource.html#minimumUpdateInterval
        -prop

        **[read-only] minimumUpdateInterval : const int**

        This property holds the minimum time (in milliseconds) required to
        retrieve a position update.

        This is the minimum value accepted by **setUpdateInterval** () and
        **requestUpdate** ().

        **Access functions:**

        virtual int **minimumUpdateInterval** () const = 0
        """
        ...

    def supportedPositioningMethods(self) -> "QGeoPositionInfoSource.PositioningMethod":
        """
        https://doc.qt.io/qt-6/qgeopositioninfosource.html#supportedPositioningM
        ethods

        **[pure virtual] QGeoPositionInfoSource::PositioningMethods
        QGeoPositionInfoSource::supportedPositioningMethods() const**

        Returns the positioning methods available to this source. Availability
        is defined as being usable at the time of calling this function.
        Therefore user settings like turned off location service or limitations
        to Satellite-based position providers are reflected by this function.
        Runtime notifications when the status changes can be obtained via
        **supportedPositioningMethodsChanged** ().

        Not all platforms distinguish the different positioning methods or
        communicate the current user configuration of the device. The following
        table provides an overview of the current platform situation:

        PlatformBrief Description
        AndroidIndividual provider status and
        general Location service state are known and communicated when location
        service is active.
        GeoClueHardcoced to always return
        **AllPositioningMethods** .
        GeoClue2Individual providers are not
        distinguishable but disabled Location services reflected.
        iOS/tvOSHardcoced to always return **AllPositioningMethods** .
        macOSHardcoced to always return **AllPositioningMethods** .
        Windows
        (UWP)Individual providers are not distinguishable but disabled Location
        services reflected.

        **See also** **supportedPositioningMethodsChanged** () and
        **setPreferredPositioningMethods** ().
        """
        ...

    def lastKnownPosition(
        self, fromSatellitePositioningMethodsOnly: bool = ...
    ) -> QGeoPositionInfo:
        """
        https://doc.qt.io/qt-6/qgeopositioninfosource.html#lastKnownPosition

        **[pure virtual] QGeoPositionInfo
        QGeoPositionInfoSource::lastKnownPosition(bool
        fromSatellitePositioningMethodsOnly = false) const**

        Returns an update containing the last known position, or a null update
        if none is available.

        If **fromSatellitePositioningMethodsOnly** is true, this returns the
        last known position received from a satellite positioning method; if
        none is available, a null update is returned.
        """
        ...

    def preferredPositioningMethods(self) -> "QGeoPositionInfoSource.PositioningMethod":
        """
        https://doc.qt.io/qt-6/qgeopositioninfosource.html#preferredPositioningM
        ethods-prop

        **[bindable] preferredPositioningMethods : PositioningMethods**

        **Note:** This property supports **QProperty**  bindings.

        Sets the preferred positioning methods for this source.

        If new methods include a method that is not supported by the source, the
        unsupported method will be ignored.

        If new methods do not include a single method available/supported by the
        source, the preferred methods will be set to the set of methods which
        the source has available. If the source has no method availabe (e.g.
        because its Location service is turned off or it does not offer a
        Location service), the passed methods are accepted as they are.

        The default value for this property is **NoPositioningMethods** .

        **Note:** Subclass implementations must call the base implementation of
        `setPreferredPositioningMethods()` to ensure
        `preferredPositioningMethods()` returns the correct value.

        **See also** **supportedPositioningMethods** ().
        """
        ...

    def setPreferredPositioningMethods(
        self, methods: "QGeoPositionInfoSource.PositioningMethod"
    ) -> None:
        """
        https://doc.qt.io/qt-6/qgeopositioninfosource.html#preferredPositioningM
        ethods-prop

        **[bindable] preferredPositioningMethods : PositioningMethods**

        **Note:** This property supports **QProperty**  bindings.

        Sets the preferred positioning methods for this source.

        If new methods include a method that is not supported by the source, the
        unsupported method will be ignored.

        If new methods do not include a single method available/supported by the
        source, the preferred methods will be set to the set of methods which
        the source has available. If the source has no method availabe (e.g.
        because its Location service is turned off or it does not offer a
        Location service), the passed methods are accepted as they are.

        The default value for this property is **NoPositioningMethods** .

        **Note:** Subclass implementations must call the base implementation of
        `setPreferredPositioningMethods()` to ensure
        `preferredPositioningMethods()` returns the correct value.

        **See also** **supportedPositioningMethods** ().
        """
        ...

    def updateInterval(self) -> int:
        """
        https://doc.qt.io/qt-6/qgeopositioninfosource.html#updateInterval-prop

        **[bindable] updateInterval : int**

        **Note:** This property supports **QProperty**  bindings.

        This property holds the requested interval in milliseconds between each
        update.

        If the update interval is not set (or is set to 0) the source will
        provide updates as often as necessary.

        If the update interval is set, the source will provide updates at an
        interval as close to the requested interval as possible. If the
        requested interval is less than the **minimumUpdateInterval** (), the
        minimum interval is used instead.

        Changes to the update interval will happen as soon as is practical,
        however the time the change takes may vary between implementations.
        Whether or not the elapsed time from the previous interval is counted as
        part of the new interval is also implementation dependent.

        The default value for this property is 0.

        **Note:** Subclass implementations must call the base implementation of
        `setUpdateInterval()` so that `updateInterval()` returns the correct
        value.

        **Note:** This property can't be used to tune update frequency on iOS
        and macOS, because their APIs do not provide such possibility. On these
        systems this parameter is only used to set **UpdateTimeoutError**  and
        trigger an **errorOccurred**  signal if the update is not received
        within the desired interval.

        **Member Function Documentation**
        """
        ...

    def setUpdateInterval(self, msec: int) -> None:
        """
        https://doc.qt.io/qt-6/qgeopositioninfosource.html#updateInterval-prop

        **[bindable] updateInterval : int**

        **Note:** This property supports **QProperty**  bindings.

        This property holds the requested interval in milliseconds between each
        update.

        If the update interval is not set (or is set to 0) the source will
        provide updates as often as necessary.

        If the update interval is set, the source will provide updates at an
        interval as close to the requested interval as possible. If the
        requested interval is less than the **minimumUpdateInterval** (), the
        minimum interval is used instead.

        Changes to the update interval will happen as soon as is practical,
        however the time the change takes may vary between implementations.
        Whether or not the elapsed time from the previous interval is counted as
        part of the new interval is also implementation dependent.

        The default value for this property is 0.

        **Note:** Subclass implementations must call the base implementation of
        `setUpdateInterval()` so that `updateInterval()` returns the correct
        value.

        **Note:** This property can't be used to tune update frequency on iOS
        and macOS, because their APIs do not provide such possibility. On these
        systems this parameter is only used to set **UpdateTimeoutError**  and
        trigger an **errorOccurred**  signal if the update is not received
        within the desired interval.

        **Member Function Documentation**
        """
        ...

    @property
    def errorOccurred(self) -> PyQt6.QtCore.pyqtBoundSignal:
        """
        https://doc.qt.io/qt-6/qgeopositioninfosource.html#errorOccurred

        **[signal] void
        QGeoPositionInfoSource::errorOccurred(QGeoPositionInfoSource::Error
        positioningError )**

        This signal is emitted after an error occurred. The **positioningError**
        parameter describes the type of error that occurred.
        """
        ...

    @property
    def positionUpdated(self) -> PyQt6.QtCore.pyqtBoundSignal:
        """
        https://doc.qt.io/qt-6/qgeopositioninfosource.html#positionUpdated

        **[signal] void QGeoPositionInfoSource::positionUpdated(const
        QGeoPositionInfo & update )**

        If **startUpdates** () or **requestUpdate** () is called, this signal is
        emitted when an update becomes available.

        The **update** value holds the value of the new update.
        """
        ...

    @property
    def supportedPositioningMethodsChanged(self) -> PyQt6.QtCore.pyqtBoundSignal:
        """
        https://doc.qt.io/qt-6/qgeopositioninfosource.html#supportedPositioningM
        ethodsChanged

        **[signal, since Qt 5.12] void
        QGeoPositionInfoSource::supportedPositioningMethodsChanged()**

        This signal is emitted when the supported positioning methods changed.
        The cause for a change could be a user turning Location services on/off
        or restricting Location services to certain types (e.g. GPS only). Note
        that changes to the supported positioning methods cannot be detected on
        all platforms. **supportedPositioningMethods** () provides an overview
        of the current platform support.

        This function was introduced in Qt 5.12.
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import typing
import PyQt6.sip


class QXmlStreamAttribute(PyQt6.sip.simplewrapper):
    """
    https://doc.qt.io/qt-6/qxmlstreamattribute.html

    **Detailed Description**

    An attribute consists of an optionally empty **namespaceUri** (), a **name**
    (), a **value** (), and an **isDefault** () attribute.

    The raw XML attribute name is returned as **qualifiedName** ().
    """

    @typing.overload
    def __init__(self) -> None:
        """
        https://doc.qt.io/qt-6/qxmlstreamattribute.html#QXmlStreamAttribute

        **QXmlStreamAttribute::QXmlStreamAttribute()**

        Creates an empty attribute.
        """
        ...

    @typing.overload
    def __init__(self, qualifiedName: str, value: str) -> None:
        """
        https://doc.qt.io/qt-6/qxmlstreamattribute.html#QXmlStreamAttribute-1

        **QXmlStreamAttribute::QXmlStreamAttribute(const QString & qualifiedName
        , const QString & value )**

        Constructs an attribute with qualified name **qualifiedName** and value
        **value**.
        """
        ...

    @typing.overload
    def __init__(self, namespaceUri: str, name: str, value: str) -> None:
        """
        https://doc.qt.io/qt-6/qxmlstreamattribute.html#QXmlStreamAttribute-2

        **QXmlStreamAttribute::QXmlStreamAttribute(const QString & namespaceUri
        , const QString & name , const QString & value )**

        Constructs an attribute in the namespace described with **namespaceUri**
        with **name** and value **value**.
        """
        ...

    @typing.overload
    def __init__(self, a0: "QXmlStreamAttribute") -> None:
        """
        https://doc.qt.io/qt-6/qxmlstreamattribute.html#QXmlStreamAttribute

        **QXmlStreamAttribute::QXmlStreamAttribute()**

        Creates an empty attribute.
        """
        ...

    def isDefault(self) -> bool:
        """
        https://doc.qt.io/qt-6/qxmlstreamattribute.html#isDefault

        **bool QXmlStreamAttribute::isDefault() const**

        Returns `true` if the parser added this attribute with a default value
        following an ATTLIST declaration in the DTD; otherwise returns `false`.
        """
        ...

    def value(self) -> str:
        """
        https://doc.qt.io/qt-6/qxmlstreamattribute.html#value

        **QStringView QXmlStreamAttribute::value() const**

        Returns the attribute's value.
        """
        ...

    def prefix(self) -> str:
        """
        https://doc.qt.io/qt-6/qxmlstreamattribute.html#prefix

        **QStringView QXmlStreamAttribute::prefix() const**

        Returns the attribute's namespace prefix.

        **See also** **name** () and **qualifiedName** ().
        """
        ...

    def qualifiedName(self) -> str:
        """
        https://doc.qt.io/qt-6/qxmlstreamattribute.html#qualifiedName

        **QStringView QXmlStreamAttribute::qualifiedName() const**

        Returns the attribute's qualified name.

        A qualified name is the raw name of an attribute in the XML data. It
        consists of the namespace **prefix** (), followed by colon, followed by
        the attribute's local **name** (). Since the namespace prefix is not
        unique (the same prefix can point to different namespaces and different
        prefixes can point to the same namespace), you shouldn't use
        qualifiedName(), but the resolved **namespaceUri** () and the
        attribute's local **name** ().
        """
        ...

    def name(self) -> str:
        """
        https://doc.qt.io/qt-6/qxmlstreamattribute.html#name

        **QStringView QXmlStreamAttribute::name() const**

        Returns the attribute's local name.
        """
        ...

    def namespaceUri(self) -> str:
        """
        https://doc.qt.io/qt-6/qxmlstreamattribute.html#namespaceUri

        **QStringView QXmlStreamAttribute::namespaceUri() const**

        Returns the attribute's resolved namespaceUri, or an empty string
        reference if the attribute does not have a defined namespace.
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import typing
from PyQt6 import QtGui
from PyQt6 import QtCore
from PyQt6.QtWidgets import *


class QItemDelegate(QAbstractItemDelegate):
    """
    https://doc.qt.io/qt-6/qitemdelegate.html

    **Detailed Description**

    QItemDelegate can be used to provide custom display features and editor
    widgets for item views based on **QAbstractItemView**  subclasses. Using a
    delegate for this purpose allows the display and editing mechanisms to be
    customized and developed independently from the model and view.

    The QItemDelegate class is one of the **Model/View Classes**  and is part of
    Qt's **model/view framework** . Note that **QStyledItemDelegate**  has taken
    over the job of drawing Qt's item views. We recommend the use of
    **QStyledItemDelegate**  when creating new delegates.

    When displaying items from a custom model in a standard view, it is often
    sufficient to simply ensure that the model returns appropriate data for each
    of the **roles**  that determine the appearance of items in views. The
    default delegate used by Qt's standard views uses this role information to
    display items in most of the common forms expected by users. However, it is
    sometimes necessary to have even more control over the appearance of items
    than the default delegate can provide.

    This class provides default implementations of the functions for painting
    item data in a view and editing data from item models. Default
    implementations of the **paint** () and **sizeHint** () virtual functions,
    defined in **QAbstractItemDelegate** , are provided to ensure that the
    delegate implements the correct basic behavior expected by views. You can
    reimplement these functions in subclasses to customize the appearance of
    items.

    When editing data in an item view, QItemDelegate provides an editor widget,
    which is a widget that is placed on top of the view while editing takes
    place. Editors are created with a **QItemEditorFactory** ; a default static
    instance provided by **QItemEditorFactory**  is installed on all item
    delegates. You can set a custom factory using **setItemEditorFactory** () or
    set a new default factory with **QItemEditorFactory::setDefaultFactory** ().
    It is the data stored in the item model with the **Qt::EditRole**  that is
    edited.

    Only the standard editing functions for widget-based delegates are
    reimplemented here:

    * **createEditor** () returns the widget used to change data from the model
    and can be reimplemented to customize editing behavior.
      *
    **setEditorData** () provides the widget with data to manipulate.
      *
    **updateEditorGeometry** () ensures that the editor is displayed correctly
    with respect to the item view.
      * **setModelData** () returns updated data
    to the model.

    The **closeEditor** () signal indicates that the user has completed editing
    the data, and that the editor widget can be destroyed.

    **Standard Roles and Data Types**

    The default delegate used by the standard views supplied with Qt associates
    each standard role (defined by **Qt::ItemDataRole** ) with certain data
    types. Models that return data in these types can influence the appearance
    of the delegate as described in the following table.

    RoleAccepted Types
    **Qt::BackgroundRole** **QBrush**  (
    **Qt::CheckStateRole** **Qt::CheckState**
    **Qt::DecorationRole** **QIcon**
    , **QPixmap**  and **QColor**
    **Qt::DisplayRole** **QString**  and types
    with a string representation
    **Qt::EditRole** See **QItemEditorFactory**
    for details
    **Qt::FontRole** **QFont**
    **Qt::SizeHintRole** **QSize**
    **Qt::TextAlignmentRole** **Qt::Alignment**
    **Qt::ForegroundRole**
    **QBrush**  (

    If the default delegate does not allow the level of customization that you
    need, either for display purposes or for editing data, it is possible to
    subclass QItemDelegate to implement the desired behavior.

    **Subclassing**

    When subclassing QItemDelegate to create a delegate that displays items
    using a custom renderer, it is important to ensure that the delegate can
    render items suitably for all the required states; e.g. selected, disabled,
    checked. The documentation for the **paint** () function contains some hints
    to show how this can be achieved.

    You can provide custom editors by using a **QItemEditorFactory** . The
    **Color Editor Factory Example**  shows how a custom editor can be made
    available to delegates with the default item editor factory. This way, there
    is no need to subclass QItemDelegate. An alternative is to reimplement
    **createEditor** (), **setEditorData** (), **setModelData** (), and
    **updateEditorGeometry** (). This process is described in the **Spin Box
    Delegate Example** .

    **QStyledItemDelegate vs. QItemDelegate**

    Since Qt 4.4, there are two delegate classes: QItemDelegate and
    **QStyledItemDelegate** . However, the default delegate is
    **QStyledItemDelegate** . These two classes are independent alternatives to
    painting and providing editors for items in views. The difference between
    them is that **QStyledItemDelegate**  uses the current style to paint its
    items. We therefore recommend using **QStyledItemDelegate**  as the base
    class when implementing custom delegates or when working with Qt style
    sheets. The code required for either class should be equal unless the custom
    delegate needs to use the style for drawing.

    **See also** **Delegate Classes** , **QStyledItemDelegate** ,
    **QAbstractItemDelegate** , **Spin Box Delegate Example** , **Settings
    Editor Example** , and **Icons Example** .
    """

    def __init__(self, parent: typing.Optional[QtCore.QObject] = ...) -> None:
        """
        https://doc.qt.io/qt-6/qitemdelegate.html#QItemDelegate

        **QItemDelegate::QItemDelegate(QObject * parent = nullptr)**

        Constructs an item delegate with the given **parent**.
        """
        ...

    def editorEvent(
        self,
        event: QtCore.QEvent,
        model: QtCore.QAbstractItemModel,
        option: "QStyleOptionViewItem",
        index: QtCore.QModelIndex,
    ) -> bool:
        """
        https://doc.qt.io/qt-6/qitemdelegate.html#editorEvent

        **[override virtual protected] bool QItemDelegate::editorEvent(QEvent *
        event , QAbstractItemModel * model , const QStyleOptionViewItem & option
        , const QModelIndex & index )**

        Reimplements: **QAbstractItemDelegate::editorEvent** (QEvent *event,
        QAbstractItemModel *model, const QStyleOptionViewItem &option, const
        QModelIndex &index).
        """
        ...

    def eventFilter(self, object: QtCore.QObject, event: QtCore.QEvent) -> bool:
        """
        https://doc.qt.io/qt-6/qitemdelegate.html#eventFilter

        **[override virtual protected] bool QItemDelegate::eventFilter(QObject *
        editor , QEvent * event )**

        Reimplements: **QObject::eventFilter** (QObject *watched, QEvent
        *event).

        Returns `true` if the given **editor** is a valid **QWidget**  and the
        given **event** is handled; otherwise returns `false`. The following key
        press events are handled by default:

        * **Tab**
          * **Backtab**
          * **Enter**
          * **Return**
          * **Esc**

        In the case of **Tab** , **Backtab** , **Enter** and **Return** key
        press events, the **editor** 's data is committed to the model and the
        editor is closed. If the **event** is a **Tab** key press the view will
        open an editor on the next item in the view. Likewise, if the **event**
        is a **Backtab** key press the view will open an editor on the
        **previous** item in the view.

        If the event is a **Esc** key press event, the **editor** is closed
        **without** committing its data.

        **See also** **commitData** () and **closeEditor** ().
        """
        ...

    def drawFocus(
        self,
        painter: QtGui.QPainter,
        option: "QStyleOptionViewItem",
        rect: QtCore.QRect,
    ) -> None:
        """
        https://doc.qt.io/qt-6/qitemdelegate.html#drawFocus

        **[virtual protected] void QItemDelegate::drawFocus(QPainter * painter ,
        const QStyleOptionViewItem & option , const QRect & rect ) const**

        Renders the region within the rectangle specified by **rect** ,
        indicating that it has the focus, using the given **painter** and style
        **option**.
        """
        ...

    def drawDisplay(
        self,
        painter: QtGui.QPainter,
        option: "QStyleOptionViewItem",
        rect: QtCore.QRect,
        text: str,
    ) -> None:
        """
        https://doc.qt.io/qt-6/qitemdelegate.html#drawDisplay

        **[virtual protected] void QItemDelegate::drawDisplay(QPainter * painter
        , const QStyleOptionViewItem & option , const QRect & rect , const
        QString & text ) const**

        Renders the item view **text** within the rectangle specified by
        **rect** using the given **painter** and style **option**.
        """
        ...

    def drawDecoration(
        self,
        painter: QtGui.QPainter,
        option: "QStyleOptionViewItem",
        rect: QtCore.QRect,
        pixmap: QtGui.QPixmap,
    ) -> None:
        """
        https://doc.qt.io/qt-6/qitemdelegate.html#drawDecoration

        **[virtual protected] void QItemDelegate::drawDecoration(QPainter *
        painter , const QStyleOptionViewItem & option , const QRect & rect ,
        const QPixmap & pixmap ) const**

        Renders the decoration **pixmap** within the rectangle specified by
        **rect** using the given **painter** and style **option**.
        """
        ...

    def drawCheck(
        self,
        painter: QtGui.QPainter,
        option: "QStyleOptionViewItem",
        rect: QtCore.QRect,
        state: QtCore.Qt.CheckState,
    ) -> None:
        """
        https://doc.qt.io/qt-6/qitemdelegate.html#drawCheck

        **[virtual protected] void QItemDelegate::drawCheck(QPainter * painter ,
        const QStyleOptionViewItem & option , const QRect & rect ,
        Qt::CheckState state ) const**

        Renders a check indicator within the rectangle specified by **rect** ,
        using the given **painter** and style **option** , using the given
        **state**.
        """
        ...

    def drawBackground(
        self,
        painter: QtGui.QPainter,
        option: "QStyleOptionViewItem",
        index: QtCore.QModelIndex,
    ) -> None:
        """
        https://doc.qt.io/qt-6/qitemdelegate.html#drawBackground

        **[protected] void QItemDelegate::drawBackground(QPainter * painter ,
        const QStyleOptionViewItem & option , const QModelIndex & index )
        const**

        Renders the item background for the given **index** , using the given
        **painter** and style **option**.
        """
        ...

    def setClipping(self, clip: bool) -> None:
        """
        https://doc.qt.io/qt-6/qitemdelegate.html#clipping-prop

        **clipping : bool**

        if the delegate should clip the paint events

        This property will set the paint clip to the size of the item. The
        default value is on. It is useful for cases such as when images are
        larger than the size of the item.

        **Access functions:**

        bool **hasClipping** () const
        void **setClipping** (bool **clip** )

        **Member Function Documentation**
        """
        ...

    def hasClipping(self) -> bool:
        ...

    def setItemEditorFactory(self, factory: "QItemEditorFactory") -> None:
        """
        https://doc.qt.io/qt-6/qitemdelegate.html#setItemEditorFactory

        **void QItemDelegate::setItemEditorFactory(QItemEditorFactory * factory
        )**

        Sets the editor factory to be used by the item delegate to be the
        **factory** specified. If no editor factory is set, the item delegate
        will use the default editor factory.

        **See also** **itemEditorFactory** ().
        """
        ...

    def itemEditorFactory(self) -> "QItemEditorFactory":
        """
        https://doc.qt.io/qt-6/qitemdelegate.html#itemEditorFactory

        **QItemEditorFactory *QItemDelegate::itemEditorFactory() const**

        Returns the editor factory used by the item delegate. If no editor
        factory is set, the function will return null.

        **See also** **setItemEditorFactory** ().
        """
        ...

    def updateEditorGeometry(
        self, editor: QWidget, option: "QStyleOptionViewItem", index: QtCore.QModelIndex
    ) -> None:
        """
        https://doc.qt.io/qt-6/qitemdelegate.html#updateEditorGeometry

        **[override virtual] void QItemDelegate::updateEditorGeometry(QWidget *
        editor , const QStyleOptionViewItem & option , const QModelIndex & index
        ) const**

        Reimplements: **QAbstractItemDelegate::updateEditorGeometry(QWidget
        *editor, const QStyleOptionViewItem &option, const QModelIndex &index)
        const** .

        Updates the **editor** for the item specified by **index** according to
        the style **option** given.
        """
        ...

    def setModelData(
        self,
        editor: QWidget,
        model: QtCore.QAbstractItemModel,
        index: QtCore.QModelIndex,
    ) -> None:
        """
        https://doc.qt.io/qt-6/qitemdelegate.html#setModelData

        **[override virtual] void QItemDelegate::setModelData(QWidget * editor ,
        QAbstractItemModel * model , const QModelIndex & index ) const**

        Reimplements: **QAbstractItemDelegate::setModelData(QWidget *editor,
        QAbstractItemModel *model, const QModelIndex &index) const** .

        Gets data from the **editor** widget and stores it in the specified
        **model** at the item **index**.

        The default implementation gets the value to be stored in the data model
        from the **editor** widget's **user property** .

        **See also** **QMetaProperty::isUser** ().
        """
        ...

    def setEditorData(self, editor: QWidget, index: QtCore.QModelIndex) -> None:
        """
        https://doc.qt.io/qt-6/qitemdelegate.html#setEditorData

        **[override virtual] void QItemDelegate::setEditorData(QWidget * editor
        , const QModelIndex & index ) const**

        Reimplements: **QAbstractItemDelegate::setEditorData(QWidget *editor,
        const QModelIndex &index) const** .

        Sets the data to be displayed and edited by the **editor** from the data
        model item specified by the model **index**.

        The default implementation stores the data in the **editor** widget's
        **user property** .

        **See also** **QMetaProperty::isUser** ().
        """
        ...

    def createEditor(
        self, parent: QWidget, option: "QStyleOptionViewItem", index: QtCore.QModelIndex
    ) -> QWidget:
        """
        https://doc.qt.io/qt-6/qitemdelegate.html#createEditor

        **[override virtual] QWidget *QItemDelegate::createEditor(QWidget *
        parent , const QStyleOptionViewItem & option , const QModelIndex & index
        ) const**

        Reimplements: **QAbstractItemDelegate::createEditor(QWidget *parent,
        const QStyleOptionViewItem &option, const QModelIndex &index) const** .

        Returns the widget used to edit the item specified by **index** for
        editing. The **parent** widget and style **option** are used to control
        how the editor widget appears.

        **See also** **QAbstractItemDelegate::createEditor** ().
        """
        ...

    def sizeHint(
        self, option: "QStyleOptionViewItem", index: QtCore.QModelIndex
    ) -> QtCore.QSize:
        """
        https://doc.qt.io/qt-6/qitemdelegate.html#sizeHint

        **[override virtual] QSize QItemDelegate::sizeHint(const
        QStyleOptionViewItem & option , const QModelIndex & index ) const**

        Reimplements: **QAbstractItemDelegate::sizeHint(const
        QStyleOptionViewItem &option, const QModelIndex &index) const** .

        Returns the size needed by the delegate to display the item specified by
        **index** , taking into account the style information provided by
        **option**.

        When reimplementing this function, note that in case of text items,
        **QItemDelegate**  adds a margin (i.e. 2 *
        **QStyle::PM_FocusFrameHMargin** ) to the length of the text.
        """
        ...

    def paint(
        self,
        painter: QtGui.QPainter,
        option: "QStyleOptionViewItem",
        index: QtCore.QModelIndex,
    ) -> None:
        """
        https://doc.qt.io/qt-6/qitemdelegate.html#paint

        **[override virtual] void QItemDelegate::paint(QPainter * painter ,
        const QStyleOptionViewItem & option , const QModelIndex & index )
        const**

        Reimplements: **QAbstractItemDelegate::paint(QPainter *painter, const
        QStyleOptionViewItem &option, const QModelIndex &index) const** .

        Renders the delegate using the given **painter** and style **option**
        for the item specified by **index**.

        When reimplementing this function in a subclass, you should update the
        area held by the option's **rect**  variable, using the option's
        **state**  variable to determine the state of the item to be displayed,
        and adjust the way it is painted accordingly.

        For example, a selected item may need to be displayed differently to
        unselected items, as shown in the following code:

        if (option.state & **QStyle** ::State_Selected)
        painter->fillRect(option.rect, option.palette.highlight());
        const int size = qMin(option.rect.width(), option.rect.height());
        const int brightness = index.model()->data(index,
        Qt::DisplayRole).toInt();
                const double radius = (size / 2.0) -
        (brightness / 255.0 * size / 2.0);
                if (qFuzzyIsNull(radius))
        return;

                painter->save();
        painter->setRenderHint(**QPainter** ::Antialiasing, true);
        painter->setPen(Qt::NoPen);
                if (option.state & **QStyle**
        ::State_Selected)
        painter->setBrush(option.palette.highlightedText());
                else
        ...

        After painting, you should ensure that the painter is returned to its
        the state it was supplied in when this function was called. For example,
        it may be useful to call **QPainter::save** () before painting and
        **QPainter::restore** () afterwards.

        **See also** **QStyle::State** .
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import typing
from PyQt6 import QtCore
from PyQt6.QtGui import *


class QBitmap(QPixmap):
    """
    https://doc.qt.io/qt-6/qbitmap.html

    **Detailed Description**

    The QBitmap class is a monochrome off-screen paint device used mainly for
    creating custom **QCursor**  and **QBrush**  objects, constructing
    **QRegion**  objects, and for setting masks for pixmaps and widgets.

    QBitmap is a **QPixmap**  subclass ensuring a depth of 1, except for null
    objects which have a depth of 0. If a pixmap with a depth greater than 1 is
    assigned to a bitmap, the bitmap will be dithered automatically.

    Use the **QColor**  objects **Qt::color0**  and **Qt::color1**  when drawing
    on a QBitmap object (or a **QPixmap**  object with depth 1).

    Painting with **Qt::color0**  sets the bitmap bits to 0, and painting with
    **Qt::color1**  sets the bits to 1. For a bitmap, 0-bits indicate background
    (or transparent pixels) and 1-bits indicate foreground (or opaque pixels).
    Use the **clear** () function to set all the bits to **Qt::color0** . Note
    that using the **Qt::black**  and **Qt::white**  colors make no sense
    because the QColor::pixel() value is not necessarily 0 for black and 1 for
    white.

    The QBitmap class provides the **transformed** () function returning a
    transformed copy of the bitmap; use the **QTransform**  argument to
    translate, scale, shear, and rotate the bitmap. In addition, QBitmap
    provides the static **fromData** () function which returns a bitmap
    constructed from the given `uchar` data, and the static **fromImage** ()
    function returning a converted copy of a **QImage**  object.

    Just like the **QPixmap**  class, QBitmap is optimized by the use of
    implicit data sharing. For more information, see the **Implicit Data
    Sharing**  documentation.

    **See also** **QPixmap** , **QImage** , **QImageReader** , and
    **QImageWriter** .
    """

    @typing.overload
    def __init__(self) -> None:
        """
        https://doc.qt.io/qt-6/qbitmap.html#QBitmap

        **QBitmap::QBitmap()**

        Constructs a null bitmap.

        **See also** **QPixmap::isNull** ().
        """
        ...

    @typing.overload
    def __init__(self, w: int, h: int) -> None:
        """
        https://doc.qt.io/qt-6/qbitmap.html#QBitmap-2

        **QBitmap::QBitmap(int width , int height )**

        Constructs a bitmap with the given **width** and **height**. The pixels
        inside are uninitialized.

        **See also** **clear** ().
        """
        ...

    @typing.overload
    def __init__(self, a0: QtCore.QSize) -> None:
        """
        https://doc.qt.io/qt-6/qbitmap.html#QBitmap-4

        **QBitmap::QBitmap(const QString & fileName , const char * format =
        nullptr)**

        Constructs a bitmap from the file specified by the given **fileName**.
        If the file does not exist, or has an unknown format, the bitmap becomes
        a null bitmap.

        The **fileName** and **format** parameters are passed on to the
        **QPixmap::load** () function. If the file format uses more than 1 bit
        per pixel, the resulting bitmap will be dithered automatically.

        **See also** **QPixmap::isNull** () and **QImageReader::imageFormat**
        ().
        """
        ...

    @typing.overload
    def __init__(self, fileName: str, format: typing.Optional[str] = ...) -> None:
        """
        https://doc.qt.io/qt-6/qbitmap.html#QBitmap

        **QBitmap::QBitmap()**

        Constructs a null bitmap.

        **See also** **QPixmap::isNull** ().
        """
        ...

    @typing.overload
    def __init__(self, variant: typing.Any) -> None:
        """
        https://doc.qt.io/qt-6/qbitmap.html#QBitmap

        **QBitmap::QBitmap()**

        Constructs a null bitmap.

        **See also** **QPixmap::isNull** ().
        """
        ...

    @typing.overload
    def __init__(self, a0: "QBitmap") -> None:
        """
        https://doc.qt.io/qt-6/qbitmap.html#QBitmap

        **QBitmap::QBitmap()**

        Constructs a null bitmap.

        **See also** **QPixmap::isNull** ().
        """
        ...

    def swap(self, other: "QBitmap") -> None:
        """
        https://doc.qt.io/qt-6/qbitmap.html#swap

        **void QBitmap::swap(QBitmap & other )**

        Swaps bitmap **other** with this bitmap. This operation is very fast and
        never fails.
        """
        ...

    def transformed(self, matrix: "QTransform") -> "QBitmap":
        """
        https://doc.qt.io/qt-6/qbitmap.html#transformed

        **QBitmap QBitmap::transformed(const QTransform & matrix ) const**

        Returns a copy of this bitmap, transformed according to the given
        **matrix**.

        **See also** **QPixmap::transformed** ().
        """
        ...

    @staticmethod
    def fromData(
        size: QtCore.QSize, bits: bytes, format: "QImage.Format" = ...
    ) -> "QBitmap":
        """
        https://doc.qt.io/qt-6/qbitmap.html#fromData

        **[static] QBitmap QBitmap::fromData(const QSize & size , const uchar *
        bits , QImage::Format monoFormat = QImage::Format_MonoLSB)**

        Constructs a bitmap with the given **size** , and sets the contents to
        the **bits** supplied.

        The bitmap data has to be byte aligned and provided in in the bit order
        specified by **monoFormat**. The mono format must be either
        **QImage::Format_Mono**  or **QImage::Format_MonoLSB** . Use
        **QImage::Format_Mono**  to specify data on the XBM format.

        **See also** **fromImage** ().
        """
        ...

    @staticmethod
    def fromPixmap(pixmap: QPixmap) -> "QBitmap":
        """
        https://doc.qt.io/qt-6/qbitmap.html#fromPixmap

        **[static] QBitmap QBitmap::fromPixmap(const QPixmap & pixmap )**

        Returns a copy of the given **pixmap** converted to a bitmap.

        If the pixmap has a depth greater than 1, the resulting bitmap will be
        dithered automatically.

        **See also** **QPixmap::depth** ().
        """
        ...

    @staticmethod
    def fromImage(
        image: "QImage", flags: QtCore.Qt.ImageConversionFlag = ...
    ) -> "QBitmap":
        """
        https://doc.qt.io/qt-6/qbitmap.html#fromImage

        **[static] QBitmap QBitmap::fromImage(const QImage & image ,
        Qt::ImageConversionFlags flags = Qt::AutoColor)**

        Returns a copy of the given **image** converted to a bitmap using the
        specified image conversion **flags**.

        **See also** **fromData** ().
        """
        ...

    def clear(self) -> None:
        """
        https://doc.qt.io/qt-6/qbitmap.html#clear

        **void QBitmap::clear()**

        Clears the bitmap, setting all its bits to **Qt::color0** .
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import typing
import PyQt6.sip
from PyQt6 import QtGui
from PyQt6 import QtCore
from PyQt6.QtWidgets import *


class QColumnView(QAbstractItemView):
    """
    https://doc.qt.io/qt-6/qcolumnview.html

    **Detailed Description**

    QColumnView displays a model in a number of QListViews, one for each
    hierarchy in the tree. This is sometimes referred to as a cascading list.

    The QColumnView class is one of the **Model/View Classes**  and is part of
    Qt's **model/view framework** .

    QColumnView implements the interfaces defined by the **QAbstractItemView**
    class to allow it to display data provided by models derived from the
    **QAbstractItemModel**  class.

    ![](images/qcolumnview.png)

    **See also** **Model/View Programming** .
    """

    def __init__(self, parent: typing.Optional[QWidget] = ...) -> None:
        """
        https://doc.qt.io/qt-6/qcolumnview.html#QColumnView

        **QColumnView::QColumnView(QWidget * parent = nullptr)**

        Constructs a column view with a **parent** to represent a model's data.
        Use **setModel** () to set the model.

        **See also** **QAbstractItemModel** .
        """
        ...

    def currentChanged(
        self, current: QtCore.QModelIndex, previous: QtCore.QModelIndex
    ) -> None:
        """
        https://doc.qt.io/qt-6/qcolumnview.html#currentChanged

        **[override virtual protected] void QColumnView::currentChanged(const
        QModelIndex & current , const QModelIndex & previous )**

        Reimplements: **QAbstractItemView::currentChanged** (const QModelIndex
        &current, const QModelIndex &previous).
        """
        ...

    def rowsInserted(self, parent: QtCore.QModelIndex, start: int, end: int) -> None:
        """
        https://doc.qt.io/qt-6/qcolumnview.html#rowsInserted

        **[override virtual protected] void QColumnView::rowsInserted(const
        QModelIndex & parent , int start , int end )**

        Reimplements: **QAbstractItemView::rowsInserted** (const QModelIndex
        &parent, int start, int end).
        """
        ...

    def scrollContentsBy(self, dx: int, dy: int) -> None:
        """
        https://doc.qt.io/qt-6/qcolumnview.html#scrollContentsBy

        **[override virtual protected] void QColumnView::scrollContentsBy(int dx
        , int dy )**

        Reimplements: **QAbstractScrollArea::scrollContentsBy** (int dx, int
        dy).
        """
        ...

    def verticalOffset(self) -> int:
        """
        https://doc.qt.io/qt-6/qcolumnview.html#verticalOffset

        **[override virtual protected] int QColumnView::verticalOffset() const**

        Reimplements: **QAbstractItemView::verticalOffset() const** .
        """
        ...

    def horizontalOffset(self) -> int:
        """
        https://doc.qt.io/qt-6/qcolumnview.html#horizontalOffset

        **[override virtual protected] int QColumnView::horizontalOffset()
        const**

        Reimplements: **QAbstractItemView::horizontalOffset() const** .
        """
        ...

    def visualRegionForSelection(
        self, selection: QtCore.QItemSelection
    ) -> QtGui.QRegion:
        """
        https://doc.qt.io/qt-6/qcolumnview.html#visualRegionForSelection

        **[override virtual protected] QRegion
        QColumnView::visualRegionForSelection(const QItemSelection & selection )
        const**

        Reimplements: **QAbstractItemView::visualRegionForSelection(const
        QItemSelection &selection) const** .
        """
        ...

    def setSelection(
        self, rect: QtCore.QRect, command: QtCore.QItemSelectionModel.SelectionFlag
    ) -> None:
        """
        https://doc.qt.io/qt-6/qcolumnview.html#setSelection

        **[override virtual protected] void QColumnView::setSelection(const
        QRect & rect , QItemSelectionModel::SelectionFlags command )**

        Reimplements: **QAbstractItemView::setSelection** (const QRect &rect,
        QItemSelectionModel::SelectionFlags flags).
        """
        ...

    def resizeEvent(self, event: QtGui.QResizeEvent) -> None:
        """
        https://doc.qt.io/qt-6/qcolumnview.html#resizeEvent

        **[override virtual protected] void
        QColumnView::resizeEvent(QResizeEvent * event )**

        Reimplements: **QAbstractItemView::resizeEvent** (QResizeEvent *event).
        """
        ...

    def moveCursor(
        self,
        cursorAction: QAbstractItemView.CursorAction,
        modifiers: QtCore.Qt.KeyboardModifier,
    ) -> QtCore.QModelIndex:
        """
        https://doc.qt.io/qt-6/qcolumnview.html#moveCursor

        **[override virtual protected] QModelIndex
        QColumnView::moveCursor(QAbstractItemView::CursorAction cursorAction ,
        Qt::KeyboardModifiers modifiers )**

        Reimplements: **QAbstractItemView::moveCursor**
        (QAbstractItemView::CursorAction cursorAction, Qt::KeyboardModifiers
        modifiers).

        Move left should go to the parent index Move right should go to the
        child index or down if there is no child
        """
        ...

    def isIndexHidden(self, index: QtCore.QModelIndex) -> bool:
        """
        https://doc.qt.io/qt-6/qcolumnview.html#isIndexHidden

        **[override virtual protected] bool QColumnView::isIndexHidden(const
        QModelIndex & index ) const**

        Reimplements: **QAbstractItemView::isIndexHidden(const QModelIndex
        &index) const** .
        """
        ...

    def initializeColumn(self, column: QAbstractItemView) -> None:
        """
        https://doc.qt.io/qt-6/qcolumnview.html#initializeColumn

        **[protected] void QColumnView::initializeColumn(QAbstractItemView *
        column ) const**

        Copies the behavior and options of the column view and applies them to
        the **column** such as the **iconSize** (), **textElideMode** () and
        **alternatingRowColors** (). This can be useful when reimplementing
        **createColumn** ().

        **See also** **createColumn** ().
        """
        ...

    def createColumn(self, rootIndex: QtCore.QModelIndex) -> QAbstractItemView:
        """
        https://doc.qt.io/qt-6/qcolumnview.html#createColumn

        **[virtual protected] QAbstractItemView *QColumnView::createColumn(const
        QModelIndex & index )**

        To use a custom widget for the final column when you select an item
        overload this function and return a widget. **index** is the root index
        that will be assigned to the view.

        Return the new view. **QColumnView**  will automatically take ownership
        of the widget.

        **See also** **setPreviewWidget** ().
        """
        ...

    def selectAll(self) -> None:
        """
        https://doc.qt.io/qt-6/qcolumnview.html#selectAll

        **[override virtual] void QColumnView::selectAll()**

        Reimplements: **QAbstractItemView::selectAll** ().
        """
        ...

    def setRootIndex(self, index: QtCore.QModelIndex) -> None:
        """
        https://doc.qt.io/qt-6/qcolumnview.html#setRootIndex

        **[override virtual] void QColumnView::setRootIndex(const QModelIndex &
        index )**

        Reimplements: **QAbstractItemView::setRootIndex** (const QModelIndex
        &index).
        """
        ...

    def setSelectionModel(self, selectionModel: QtCore.QItemSelectionModel) -> None:
        """
        https://doc.qt.io/qt-6/qcolumnview.html#setSelectionModel

        **[override virtual] void
        QColumnView::setSelectionModel(QItemSelectionModel * newSelectionModel
        )**

        Reimplements: **QAbstractItemView::setSelectionModel**
        (QItemSelectionModel *selectionModel).
        """
        ...

    def setModel(self, model: QtCore.QAbstractItemModel) -> None:
        """
        https://doc.qt.io/qt-6/qcolumnview.html#setModel

        **[override virtual] void QColumnView::setModel(QAbstractItemModel *
        model )**

        Reimplements: **QAbstractItemView::setModel** (QAbstractItemModel
        *model).
        """
        ...

    def visualRect(self, index: QtCore.QModelIndex) -> QtCore.QRect:
        """
        https://doc.qt.io/qt-6/qcolumnview.html#visualRect

        **[override virtual] QRect QColumnView::visualRect(const QModelIndex &
        index ) const**

        Reimplements: **QAbstractItemView::visualRect(const QModelIndex &index)
        const** .
        """
        ...

    def sizeHint(self) -> QtCore.QSize:
        """
        https://doc.qt.io/qt-6/qcolumnview.html#sizeHint

        **[override virtual] QSize QColumnView::sizeHint() const**

        Reimplements: **QAbstractScrollArea::sizeHint() const** .
        """
        ...

    def scrollTo(
        self, index: QtCore.QModelIndex, hint: QAbstractItemView.ScrollHint = ...
    ) -> None:
        """
        https://doc.qt.io/qt-6/qcolumnview.html#scrollTo

        **[override virtual] void QColumnView::scrollTo(const QModelIndex &
        index , QAbstractItemView::ScrollHint hint = EnsureVisible)**

        Reimplements: **QAbstractItemView::scrollTo** (const QModelIndex &index,
        QAbstractItemView::ScrollHint hint).
        """
        ...

    def indexAt(self, point: QtCore.QPoint) -> QtCore.QModelIndex:
        """
        https://doc.qt.io/qt-6/qcolumnview.html#indexAt

        **[override virtual] QModelIndex QColumnView::indexAt(const QPoint &
        point ) const**

        Reimplements: **QAbstractItemView::indexAt(const QPoint &point) const**
        .
        """
        ...

    def setResizeGripsVisible(self, visible: bool) -> None:
        """
        https://doc.qt.io/qt-6/qcolumnview.html#resizeGripsVisible-prop

        **resizeGripsVisible : bool**

        This property holds the way to specify if the list views gets resize
        grips or not

        By default, `visible` is set to true

        **Access functions:**

        bool **resizeGripsVisible** () const
        void **setResizeGripsVisible**
        (bool **visible** )

        **See also** **setRootIndex** ().

        **Member Function Documentation**
        """
        ...

    def setPreviewWidget(self, widget: QWidget) -> None:
        """
        https://doc.qt.io/qt-6/qcolumnview.html#setPreviewWidget

        **void QColumnView::setPreviewWidget(QWidget * widget )**

        Sets the preview **widget**.

        The **widget** becomes a child of the column view, and will be destroyed
        when the column area is deleted or when a new widget is set.

        **See also** **previewWidget** () and **updatePreviewWidget** ().
        """
        ...

    def setColumnWidths(self, list: typing.Iterable[int]) -> None:
        """
        https://doc.qt.io/qt-6/qcolumnview.html#setColumnWidths

        **void QColumnView::setColumnWidths(const QList<int> & list )**

        Sets the column widths to the values given in the **list**. Extra values
        in the list are kept and used when the columns are created.

        If list contains too few values, only width of the rest of the columns
        will not be modified.

        **See also** **columnWidths** () and **createColumn** ().
        """
        ...

    def resizeGripsVisible(self) -> bool:
        """
        https://doc.qt.io/qt-6/qcolumnview.html#resizeGripsVisible-prop

        **resizeGripsVisible : bool**

        This property holds the way to specify if the list views gets resize
        grips or not

        By default, `visible` is set to true

        **Access functions:**

        bool **resizeGripsVisible** () const
        void **setResizeGripsVisible**
        (bool **visible** )

        **See also** **setRootIndex** ().

        **Member Function Documentation**
        """
        ...

    def previewWidget(self) -> QWidget:
        """
        https://doc.qt.io/qt-6/qcolumnview.html#previewWidget

        **QWidget *QColumnView::previewWidget() const**

        Returns the preview widget, or `nullptr` if there is none.

        **See also** **setPreviewWidget** () and **updatePreviewWidget** ().
        """
        ...

    def columnWidths(self) -> typing.List[int]:
        """
        https://doc.qt.io/qt-6/qcolumnview.html#columnWidths

        **QList<int> QColumnView::columnWidths() const**

        Returns a list of the width of all the columns in this view.

        **See also** **setColumnWidths** ().
        """
        ...

    @property
    def updatePreviewWidget(self) -> PyQt6.QtCore.pyqtBoundSignal:
        """
        https://doc.qt.io/qt-6/qcolumnview.html#updatePreviewWidget

        **[signal] void QColumnView::updatePreviewWidget(const QModelIndex &
        index )**

        This signal is emitted when the preview widget should be updated to
        provide rich information about **index**

        **See also** **previewWidget** ().
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import typing
import PyQt6.sip
from PyQt6.QtQml import *


class QJSValueIterator(PyQt6.sip.simplewrapper):
    """
    https://doc.qt.io/qt-6/qjsvalueiterator.html

    **Detailed Description**

    The QJSValueIterator constructor takes a **QJSValue**  as argument. After
    construction, the iterator is located at the very beginning of the sequence
    of properties. Here's how to iterate over all the properties of a
    **QJSValue** :

    **QJSValue**  object;
        ...
        **QJSValueIterator**  it(object);
    while (it.hasNext()) {
            it.next();
            **qDebug** () << it.name()
    << ": " << it.value().toString();
        }

    The **next** () advances the iterator. The **name** () and **value** ()
    functions return the name and value of the last item that was jumped over.

    Note that QJSValueIterator only iterates over the **QJSValue** 's own
    properties; i.e. it does not follow the prototype chain. You can use a loop
    like this to follow the prototype chain:

    **QJSValue**  obj = ...; // the object to iterate over
        while
    (obj.isObject()) {
            **QJSValueIterator**  it(obj);
            while
    (it.hasNext()) {
                it.next();
                **qDebug** () <<
    it.name();
            }
            obj = obj.prototype();
        }

    **See also** **QJSValue::property** ().
    """

    def __init__(
        self,
        value: typing.Union[QJSValue, QJSValue.SpecialValue, bool, int, float, str],
    ) -> None:
        """
        https://doc.qt.io/qt-6/qjsvalueiterator.html#QJSValueIterator

        **QJSValueIterator::QJSValueIterator(const QJSValue & object )**

        Constructs an iterator for traversing **object**. The iterator is set to
        be at the front of the sequence of properties (before the first
        property).
        """
        ...

    def value(self) -> QJSValue:
        """
        https://doc.qt.io/qt-6/qjsvalueiterator.html#value

        **QJSValue QJSValueIterator::value() const**

        Returns the value of the last property that was jumped over using
        **next** ().

        **See also** **name** ().
        """
        ...

    def name(self) -> str:
        """
        https://doc.qt.io/qt-6/qjsvalueiterator.html#name

        **QString QJSValueIterator::name() const**

        Returns the name of the last property that was jumped over using
        **next** ().

        **See also** **value** ().
        """
        ...

    def next(self) -> bool:
        """
        https://doc.qt.io/qt-6/qjsvalueiterator.html#next

        **bool QJSValueIterator::next()**

        Advances the iterator by one position. Returns true if there was at
        least one item ahead of the iterator (i.e. the iterator was **not**
        already at the back of the property sequence); otherwise returns false.

        **See also** **hasNext** () and **name** ().
        """
        ...

    def hasNext(self) -> bool:
        """
        https://doc.qt.io/qt-6/qjsvalueiterator.html#hasNext

        **bool QJSValueIterator::hasNext() const**

        Returns true if there is at least one item ahead of the iterator (i.e.
        the iterator is **not** at the back of the property sequence); otherwise
        returns false.

        **See also** **next** ().
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import typing
from PyQt6 import QtCore
from PyQt6.QtGui import *


class QActionEvent(QtCore.QEvent):
    """
    https://doc.qt.io/qt-6/qactionevent.html

    **Detailed Description**

    Actions can be added to controls, for example by using
    **QWidget::addAction** (). This generates an **ActionAdded**  event, which
    you can handle to provide custom behavior. For example, **QToolBar**
    reimplements **QWidget::actionEvent** () to create **QToolButton** s for the
    actions.

    **See also** **QAction** , **QWidget::addAction** (),
    **QWidget::removeAction** (), and **QWidget::actions** ().
    """

    def __init__(
        self, type: int, action: QAction, before: typing.Optional[QAction] = ...
    ) -> None:
        """
        https://doc.qt.io/qt-6/qactionevent.html#QActionEvent-2

        **QActionEvent::QActionEvent(int type , QAction * action , QAction *
        before = nullptr)**

        Constructs an action event. The **type** can be **ActionChanged** ,
        **ActionAdded** , or **ActionRemoved** .

        **action** is the action that is changed, added, or removed. If **type**
        is ActionAdded, the action is to be inserted before the action
        **before**. If **before** is `nullptr`, the action is appended.
        """
        ...

    def clone(self) -> "QActionEvent":
        ...

    def before(self) -> QAction:
        """
        https://doc.qt.io/qt-6/qactionevent.html#before

        **QAction *QActionEvent::before() const**

        If **type** () is **ActionAdded** , returns the action that should
        appear before **action** (). If this function returns `nullptr`, the
        action should be appended to already existing actions on the same
        widget.

        **See also** **action** () and **QWidget::actions** ().
        """
        ...

    def action(self) -> QAction:
        """
        https://doc.qt.io/qt-6/qactionevent.html#action

        **QAction *QActionEvent::action() const**

        Returns the action that is changed, added, or removed.

        **See also** **before** ().
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import typing
import PyQt6.sip
from PyQt6 import QtGui
from PyQt6 import QtCore
from PyQt6.QtWidgets import *


class QSplitter(QFrame):
    """
    https://doc.qt.io/qt-6/qsplitter.html

    **Detailed Description**

    A splitter lets the user control the size of child widgets by dragging the
    boundary between them. Any number of widgets may be controlled by a single
    splitter. The typical use of a QSplitter is to create several widgets and
    add them using **insertWidget** () or **addWidget** ().

    The following example will show a **QListView** , **QTreeView** , and
    **QTextEdit**  side by side, with two splitter handles:

    **QSplitter**  *splitter = new **QSplitter** (parent);
            **QListView**
    *listview = new **QListView** ;
            **QTreeView**  *treeview = new
    **QTreeView** ;
            **QTextEdit**  *textedit = new **QTextEdit** ;
    splitter->addWidget(listview);
            splitter->addWidget(treeview);
    splitter->addWidget(textedit);

    If a widget is already inside a QSplitter when **insertWidget** () or
    **addWidget** () is called, it will move to the new position. This can be
    used to reorder widgets in the splitter later. You can use **indexOf** (),
    **widget** (), and **count** () to get access to the widgets inside the
    splitter.

    A default QSplitter lays out its children horizontally (side by side); you
    can use **setOrientation** (**Qt::Vertical** ) to lay its children out
    vertically.

    By default, all widgets can be as large or as small as the user wishes,
    between the **minimumSizeHint** () (or **minimumSize** ()) and
    **maximumSize** () of the widgets.

    QSplitter resizes its children dynamically by default. If you would rather
    have QSplitter resize the children only at the end of a resize operation,
    call **setOpaqueResize** (false).

    The initial distribution of size between the widgets is determined by
    multiplying the initial size with the stretch factor. You can also use
    **setSizes** () to set the sizes of all the widgets. The function **sizes**
    () returns the sizes set by the user. Alternatively, you can save and
    restore the sizes of the widgets from a **QByteArray**  using **saveState**
    () and **restoreState** () respectively.

    When you **hide** () a child, its space will be distributed among the other
    children. It will be reinstated when you **show** () it again.

    **Note:** Adding a **QLayout**  to a QSplitter is not supported (either
    through **setLayout** () or making the QSplitter a parent of the **QLayout**
    ); use **addWidget** () instead (see example above).

    **See also** **QSplitterHandle** , **QHBoxLayout** , **QVBoxLayout** , and
    **QTabWidget** .
    """

    @typing.overload
    def __init__(self, parent: typing.Optional[QWidget] = ...) -> None:
        """
        https://doc.qt.io/qt-6/qsplitter.html#QSplitter

        **QSplitter::QSplitter(QWidget * parent = nullptr)**

        Constructs a horizontal splitter with the **parent** argument passed on
        to the **QFrame**  constructor.

        **See also** **setOrientation** ().
        """
        ...

    @typing.overload
    def __init__(
        self, orientation: QtCore.Qt.Orientation, parent: typing.Optional[QWidget] = ...
    ) -> None:
        """
        https://doc.qt.io/qt-6/qsplitter.html#QSplitter-1

        **QSplitter::QSplitter(Qt::Orientation orientation , QWidget * parent =
        nullptr)**

        Constructs a splitter with the given **orientation** and **parent**.

        **See also** **setOrientation** ().
        """
        ...

    def closestLegalPosition(self, a0: int, a1: int) -> int:
        """
        https://doc.qt.io/qt-6/qsplitter.html#closestLegalPosition

        **[protected] int QSplitter::closestLegalPosition(int pos , int index
        )**

        Returns the closest legal position to **pos** of the widget at
        **index**.

        For right-to-left languages such as Arabic and Hebrew, the layout of
        horizontal splitters is reversed. Positions are then measured from the
        right edge of the widget.

        **See also** **getRange** ().
        """
        ...

    def setRubberBand(self, position: int) -> None:
        """
        https://doc.qt.io/qt-6/qsplitter.html#setRubberBand

        **[protected] void QSplitter::setRubberBand(int pos )**

        Displays a rubber band at position **pos**. If **pos** is negative, the
        rubber band is removed.
        """
        ...

    def moveSplitter(self, pos: int, index: int) -> None:
        """
        https://doc.qt.io/qt-6/qsplitter.html#moveSplitter

        **[protected] void QSplitter::moveSplitter(int pos , int index )**

        Moves the left or top edge of the splitter handle at **index** as close
        as possible to position **pos** , which is the distance from the left or
        top edge of the widget.

        For right-to-left languages such as Arabic and Hebrew, the layout of
        horizontal splitters is reversed. **pos** is then the distance from the
        right edge of the widget.

        **See also** **splitterMoved** (), **closestLegalPosition** (), and
        **getRange** ().
        """
        ...

    def changeEvent(self, a0: QtCore.QEvent) -> None:
        """
        https://doc.qt.io/qt-6/qsplitter.html#changeEvent

        **[override virtual protected] void QSplitter::changeEvent(QEvent * ev
        )**

        Reimplements: **QFrame::changeEvent** (QEvent *ev).
        """
        ...

    def resizeEvent(self, a0: QtGui.QResizeEvent) -> None:
        """
        https://doc.qt.io/qt-6/qsplitter.html#resizeEvent

        **[override virtual protected] void QSplitter::resizeEvent(QResizeEvent
        *)**

        Reimplements: **QWidget::resizeEvent** (QResizeEvent *event).
        """
        ...

    def event(self, a0: QtCore.QEvent) -> bool:
        """
        https://doc.qt.io/qt-6/qsplitter.html#event

        **[override virtual protected] bool QSplitter::event(QEvent * e )**

        Reimplements: **QFrame::event** (QEvent *e).
        """
        ...

    def childEvent(self, a0: QtCore.QChildEvent) -> None:
        """
        https://doc.qt.io/qt-6/qsplitter.html#childEvent

        **[override virtual protected] void QSplitter::childEvent(QChildEvent *
        c )**

        Reimplements: **QObject::childEvent** (QChildEvent *event).

        Tells the splitter that the child widget described by **c** has been
        inserted or removed.

        This method is also used to handle the situation where a widget is
        created with the splitter as a parent but not explicitly added with
        **insertWidget** () or **addWidget** (). This is for compatibility and
        not the recommended way of putting widgets into a splitter in new code.
        Please use **insertWidget** () or **addWidget** () in new code.

        **See also** **addWidget** () and **insertWidget** ().
        """
        ...

    def createHandle(self) -> "QSplitterHandle":
        """
        https://doc.qt.io/qt-6/qsplitter.html#createHandle

        **[virtual protected] QSplitterHandle *QSplitter::createHandle()**

        Returns a new splitter handle as a child widget of this splitter. This
        function can be reimplemented in subclasses to provide support for
        custom handles.

        **See also** **handle** () and **indexOf** ().
        """
        ...

    def replaceWidget(self, index: int, widget: QWidget) -> QWidget:
        """
        https://doc.qt.io/qt-6/qsplitter.html#replaceWidget

        **[since 5.9] QWidget *QSplitter::replaceWidget(int index , QWidget *
        widget )**

        Replaces the widget in the splitter's layout at the given **index** by
        **widget**.

        Returns the widget that has just been replaced if **index** is valid and
        **widget** is not already a child of the splitter. Otherwise, it returns
        null and no replacement or addition is made.

        The geometry of the newly inserted widget will be the same as the widget
        it replaces. Its visible and collapsed states are also inherited.

        **Note:** The splitter takes ownership of **widget** and sets the parent
        of the replaced widget to null.

        **Note:** Because **widget** gets **reparented**  into the splitter, its
        **geometry**  may not be set right away, but only after **widget** will
        receive the appropriate events.

        This function was introduced in Qt 5.9.

        **See also** **insertWidget** () and **indexOf** ().
        """
        ...

    def setStretchFactor(self, index: int, stretch: int) -> None:
        """
        https://doc.qt.io/qt-6/qsplitter.html#setStretchFactor

        **void QSplitter::setStretchFactor(int index , int stretch )**

        Updates the size policy of the widget at position **index** to have a
        stretch factor of **stretch**.

        **stretch** is not the effective stretch factor; the effective stretch
        factor is calculated by taking the initial size of the widget and
        multiplying it with **stretch**.

        This function is provided for convenience. It is equivalent to

        **QWidget**  *widget = splitter->widget(index);
            **QSizePolicy**
        policy = widget->sizePolicy();
            policy.setHorizontalStretch(stretch);
        policy.setVerticalStretch(stretch);
            widget->setSizePolicy(policy);

        **See also** **setSizes** () and **widget** ().
        """
        ...

    def handle(self, index: int) -> "QSplitterHandle":
        """
        https://doc.qt.io/qt-6/qsplitter.html#handle

        **QSplitterHandle *QSplitter::handle(int index ) const**

        Returns the handle to the left of (or above) the item in the splitter's
        layout at the given **index** , or `nullptr` if there is no such item.
        The handle at index 0 is always hidden.

        For right-to-left languages such as Arabic and Hebrew, the layout of
        horizontal splitters is reversed. The handle will be to the right of the
        widget at **index**.

        **See also** **count** (), **widget** (), **indexOf** (),
        **createHandle** (), and **setHandleWidth** ().
        """
        ...

    def getRange(self, index: int) -> typing.Tuple[int, int]:
        """
        https://doc.qt.io/qt-6/qsplitter.html#getRange

        **void QSplitter::getRange(int index , int * min , int * max ) const**

        Returns the valid range of the splitter at **index** in * **min** and *
        **max** if **min** and **max** are not 0.
        """
        ...

    def __len__(self) -> int:
        ...

    def count(self) -> int:
        """
        https://doc.qt.io/qt-6/qsplitter.html#count

        **int QSplitter::count() const**

        Returns the number of widgets contained in the splitter's layout.

        **See also** **widget** () and **handle** ().
        """
        ...

    def widget(self, index: int) -> QWidget:
        """
        https://doc.qt.io/qt-6/qsplitter.html#widget

        **QWidget *QSplitter::widget(int index ) const**

        Returns the widget at the given **index** in the splitter's layout, or
        `nullptr` if there is no such widget.

        **See also** **count** (), **handle** (), **indexOf** (), and
        **insertWidget** ().
        """
        ...

    def indexOf(self, w: QWidget) -> int:
        """
        https://doc.qt.io/qt-6/qsplitter.html#indexOf

        **int QSplitter::indexOf(QWidget * widget ) const**

        Returns the index in the splitter's layout of the specified **widget** ,
        or -1 if **widget** is not found. This also works for handles.

        Handles are numbered from 0. There are as many handles as there are
        child widgets, but the handle at position 0 is always hidden.

        **See also** **count** () and **widget** ().
        """
        ...

    def setHandleWidth(self, a0: int) -> None:
        """
        https://doc.qt.io/qt-6/qsplitter.html#handleWidth-prop

        **handleWidth : int**

        This property holds the width of the splitter handles

        By default, this property contains a value that depends on the user's
        platform and style preferences.

        If you set handleWidth to 1 or 0, the actual grab area will grow to
        overlap a few pixels of its respective widgets.

        **Access functions:**

        int **handleWidth** () const
        void **setHandleWidth** (int)
        """
        ...

    def handleWidth(self) -> int:
        """
        https://doc.qt.io/qt-6/qsplitter.html#handleWidth-prop

        **handleWidth : int**

        This property holds the width of the splitter handles

        By default, this property contains a value that depends on the user's
        platform and style preferences.

        If you set handleWidth to 1 or 0, the actual grab area will grow to
        overlap a few pixels of its respective widgets.

        **Access functions:**

        int **handleWidth** () const
        void **setHandleWidth** (int)
        """
        ...

    def restoreState(self, state: QtCore.QByteArray) -> bool:
        """
        https://doc.qt.io/qt-6/qsplitter.html#restoreState

        **bool QSplitter::restoreState(const QByteArray & state )**

        Restores the splitter's layout to the **state** specified. Returns
        `true` if the state is restored; otherwise returns `false`.

        Typically this is used in conjunction with **QSettings**  to restore the
        size from a past session. Here is an example:

        Restore the splitter's state:

        **QSettings**  settings;
        splitter->restoreState(settings.value("splitterSizes").toByteArray());

        A failure to restore the splitter's layout may result from either
        invalid or out-of-date data in the supplied byte array.

        **See also** **saveState** ().
        """
        ...

    def saveState(self) -> QtCore.QByteArray:
        """
        https://doc.qt.io/qt-6/qsplitter.html#saveState

        **QByteArray QSplitter::saveState() const**

        Saves the state of the splitter's layout.

        Typically this is used in conjunction with **QSettings**  to remember
        the size for a future session. A version number is stored as part of the
        data. Here is an example:

        **QSettings**  settings;
                settings.setValue("splitterSizes",
        splitter->saveState());

        **See also** **restoreState** ().
        """
        ...

    def setSizes(self, list: typing.Iterable[int]) -> None:
        """
        https://doc.qt.io/qt-6/qsplitter.html#setSizes

        **void QSplitter::setSizes(const QList<int> & list )**

        Sets the child widgets' respective sizes to the values given in the
        **list**.

        If the splitter is horizontal, the values set the width of each widget
        in pixels, from left to right. If the splitter is vertical, the height
        of each widget is set, from top to bottom.

        Extra values in the **list** are ignored. If **list** contains too few
        values, the result is undefined, but the program will still be well-
        behaved.

        The overall size of the splitter widget is not affected. Instead, any
        additional/missing space is distributed amongst the widgets according to
        the relative weight of the sizes.

        If you specify a size of 0, the widget will be invisible. The size
        policies of the widgets are preserved. That is, a value smaller than the
        minimal size hint of the respective widget will be replaced by the value
        of the hint.

        **See also** **sizes** ().
        """
        ...

    def sizes(self) -> typing.List[int]:
        """
        https://doc.qt.io/qt-6/qsplitter.html#sizes

        **QList<int> QSplitter::sizes() const**

        Returns a list of the size parameters of all the widgets in this
        splitter.

        If the splitter's orientation is horizontal, the list contains the
        widgets width in pixels, from left to right; if the orientation is
        vertical, the list contains the widgets' heights in pixels, from top to
        bottom.

        Giving the values to another splitter's **setSizes** () function will
        produce a splitter with the same layout as this one.

        Note that invisible widgets have a size of 0.

        **See also** **setSizes** ().
        """
        ...

    def minimumSizeHint(self) -> QtCore.QSize:
        """
        https://doc.qt.io/qt-6/qsplitter.html#minimumSizeHint

        **[override virtual] QSize QSplitter::minimumSizeHint() const**

        Reimplements an access function for property:
        **QWidget::minimumSizeHint** .
        """
        ...

    def sizeHint(self) -> QtCore.QSize:
        """
        https://doc.qt.io/qt-6/qsplitter.html#sizeHint

        **[override virtual] QSize QSplitter::sizeHint() const**

        Reimplements: **QFrame::sizeHint() const** .
        """
        ...

    def refresh(self) -> None:
        """
        https://doc.qt.io/qt-6/qsplitter.html#refresh

        **void QSplitter::refresh()**

        Updates the splitter's state. You should not need to call this function.
        """
        ...

    def opaqueResize(self) -> bool:
        """
        https://doc.qt.io/qt-6/qsplitter.html#opaqueResize-prop

        **opaqueResize : bool**

        Returns `true` if widgets are resized dynamically (opaquely) while
        interactively moving the splitter. Otherwise returns `false`.

        The default resize behavior is style dependent (determined by the
        SH_Splitter_OpaqueResize style hint). However, you can override it by
        calling setOpaqueResize()

        **Access functions:**

        bool **opaqueResize** () const
        void **setOpaqueResize** (bool
        **opaque** = true)

        **See also** **QStyle::StyleHint** .
        """
        ...

    def setOpaqueResize(self, opaque: bool = ...) -> None:
        """
        https://doc.qt.io/qt-6/qsplitter.html#opaqueResize-prop

        **opaqueResize : bool**

        Returns `true` if widgets are resized dynamically (opaquely) while
        interactively moving the splitter. Otherwise returns `false`.

        The default resize behavior is style dependent (determined by the
        SH_Splitter_OpaqueResize style hint). However, you can override it by
        calling setOpaqueResize()

        **Access functions:**

        bool **opaqueResize** () const
        void **setOpaqueResize** (bool
        **opaque** = true)

        **See also** **QStyle::StyleHint** .
        """
        ...

    def isCollapsible(self, index: int) -> bool:
        """
        https://doc.qt.io/qt-6/qsplitter.html#isCollapsible

        **bool QSplitter::isCollapsible(int index ) const**

        Returns `true` if the widget at **index** is collapsible, otherwise
        returns `false`.
        """
        ...

    def setCollapsible(self, index: int, a1: bool) -> None:
        """
        https://doc.qt.io/qt-6/qsplitter.html#setCollapsible

        **void QSplitter::setCollapsible(int index , bool collapse )**

        Sets whether the child widget at **index** is collapsible to
        **collapse**.

        By default, children are collapsible, meaning that the user can resize
        them down to size 0, even if they have a non-zero **minimumSize** () or
        **minimumSizeHint** (). This behavior can be changed on a per-widget
        basis by calling this function, or globally for all the widgets in the
        splitter by setting the **childrenCollapsible**  property.

        **See also** **isCollapsible** () and **childrenCollapsible** .
        """
        ...

    def childrenCollapsible(self) -> bool:
        """
        https://doc.qt.io/qt-6/qsplitter.html#childrenCollapsible-prop

        **childrenCollapsible : bool**

        This property holds whether child widgets can be resized down to size 0
        by the user

        By default, children are collapsible. It is possible to enable and
        disable the collapsing of individual children using **setCollapsible**
        ().

        **Access functions:**

        bool **childrenCollapsible** () const
        void **setChildrenCollapsible**
        (bool)

        **See also** **setCollapsible** ().
        """
        ...

    def setChildrenCollapsible(self, a0: bool) -> None:
        """
        https://doc.qt.io/qt-6/qsplitter.html#childrenCollapsible-prop

        **childrenCollapsible : bool**

        This property holds whether child widgets can be resized down to size 0
        by the user

        By default, children are collapsible. It is possible to enable and
        disable the collapsing of individual children using **setCollapsible**
        ().

        **Access functions:**

        bool **childrenCollapsible** () const
        void **setChildrenCollapsible**
        (bool)

        **See also** **setCollapsible** ().
        """
        ...

    def orientation(self) -> QtCore.Qt.Orientation:
        """
        https://doc.qt.io/qt-6/qsplitter.html#orientation-prop

        **orientation : Qt::Orientation**

        This property holds the orientation of the splitter

        By default, the orientation is horizontal (i.e., the widgets are laid
        out side by side). The possible orientations are **Qt::Horizontal**  and
        **Qt::Vertical** .

        **Access functions:**

        Qt::Orientation **orientation** () const
        void **setOrientation**
        (Qt::Orientation)

        **See also** **QSplitterHandle::orientation** ().

        **Member Function Documentation**
        """
        ...

    def setOrientation(self, a0: QtCore.Qt.Orientation) -> None:
        """
        https://doc.qt.io/qt-6/qsplitter.html#orientation-prop

        **orientation : Qt::Orientation**

        This property holds the orientation of the splitter

        By default, the orientation is horizontal (i.e., the widgets are laid
        out side by side). The possible orientations are **Qt::Horizontal**  and
        **Qt::Vertical** .

        **Access functions:**

        Qt::Orientation **orientation** () const
        void **setOrientation**
        (Qt::Orientation)

        **See also** **QSplitterHandle::orientation** ().

        **Member Function Documentation**
        """
        ...

    def insertWidget(self, index: int, widget: QWidget) -> None:
        """
        https://doc.qt.io/qt-6/qsplitter.html#insertWidget

        **void QSplitter::insertWidget(int index , QWidget * widget )**

        Inserts the **widget** specified into the splitter's layout at the given
        **index**.

        If **widget** is already in the splitter, it will be moved to the new
        position.

        If **index** is an invalid index, then the widget will be inserted at
        the end.

        **Note:** The splitter takes ownership of the widget.

        **See also** **addWidget** (), **indexOf** (), and **widget** ().
        """
        ...

    def addWidget(self, widget: QWidget) -> None:
        """
        https://doc.qt.io/qt-6/qsplitter.html#addWidget

        **void QSplitter::addWidget(QWidget * widget )**

        Adds the given **widget** to the splitter's layout after all the other
        items.

        If **widget** is already in the splitter, it will be moved to the new
        position.

        **Note:** The splitter takes ownership of the widget.

        **See also** **insertWidget** (), **widget** (), and **indexOf** ().
        """
        ...

    @property
    def splitterMoved(self) -> PyQt6.QtCore.pyqtBoundSignal:
        """
        https://doc.qt.io/qt-6/qsplitter.html#splitterMoved

        **[signal] void QSplitter::splitterMoved(int pos , int index )**

        This signal is emitted when the splitter handle at a particular
        **index** has been moved to position **pos**.

        For right-to-left languages such as Arabic and Hebrew, the layout of
        horizontal splitters is reversed. **pos** is then the distance from the
        right edge of the widget.

        **See also** **moveSplitter** ().
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import typing
import PyQt6.sip


class QDesignerPropertySheetExtension(PyQt6.sip.simplewrapper):
    """
    https://doc.qt.io/qt-6/qdesignerpropertysheetextension.html

    **Detailed Description**

    QDesignerPropertySheetExtension provides a collection of functions that are
    typically used to query a widget's properties, and to manipulate the
    properties' appearance in the property editor. For example:

    QDesignerPropertySheetExtension *propertySheet  = 0;
    **QExtensionManager**  manager = formEditor->extensionManager();
    propertySheet = qt_extension<QDesignerPropertySheetExtension*>(manager,
    widget);
        int index = propertySheet->indexOf(QLatin1String("margin"));
    propertySheet->setProperty(index, 10);
        propertySheet->setChanged(index,
    true);

        delete propertySheet;

    Note that if you change the value of a property using the
    **QDesignerPropertySheetExtension::setProperty** () function, the undo stack
    is not updated. To ensure that a property's value can be reverted using the
    undo stack, you must use the
    **QDesignerFormWindowCursorInterface::setProperty** () function, or its
    buddy **setWidgetProperty** (), instead.

    When implementing a custom widget plugin, a pointer to **Qt Designer** 's
    current **QDesignerFormEditorInterface**  object (`formEditor` in the
    example above) is provided by the
    **QDesignerCustomWidgetInterface::initialize** () function's parameter.

    The property sheet, or any other extension, can be retrieved by querying
    **Qt Designer** 's extension manager using the **qt_extension** () function.
    When you want to release the extension, you only need to delete the pointer.

    All widgets have a default property sheet which populates **Qt Designer** 's
    property editor with the widget's properties (i.e the ones defined with the
    **Q_PROPERTY** () macro). But QDesignerPropertySheetExtension also provides
    an interface for creating custom property sheet extensions.

    Keep the following limitations in mind:

    * **Qt Designer** uses the QDesignerPropertySheetExtension to feed its
    property editor. Whenever a widget is selected in its workspace, **Qt
    Designer** will query for the widget's property sheet extension. If the
    selected widget has an implemented property sheet extension, this extension
    will override the default property sheet.
      * The data types used by the
    property sheet for some properties are opaque custom **QVariant**  types
    containing additional information instead of plain Qt data types. For
    example, this is the case for enumerations, flags, icons, pixmaps and
    strings.
      * **Qt Designer** 's property editor has no implementation for
    handling **Q_PROPERTY**  types for custom types that have been declared with
    **Q_DECLARE_METATYPE** ().

    To create a property sheet extension, your extension class must inherit from
    both **QObject**  and QDesignerPropertySheetExtension. Then, since we are
    implementing an interface, we must ensure that it's made known to the meta
    object system using the **Q_INTERFACES** () macro:

    class MyPropertySheetExtension : public **QObject** ,
                public
    QDesignerPropertySheetExtension
        {
            Q_OBJECT
    Q_INTERFACES(QDesignerPropertySheetExtension)

        public:
            ...
    }

    This enables **Qt Designer** to use **qobject_cast** () to query for
    supported interfaces using nothing but a **QObject**  pointer.

    In **Qt Designer** the extensions are not created until they are required.
    For that reason, when implementing a property sheet extension, you must also
    create a **QExtensionFactory** , i.e a class that is able to make an
    instance of your extension, and register it using **Qt Designer** 's
    **extension manager** .

    When a property sheet extension is required, **Qt Designer** 's **extension
    manager**  will run through all its registered factories calling
    **QExtensionFactory::createExtension** () for each until the first one that
    is able to create a property sheet extension for the selected widget, is
    found. This factory will then make an instance of the extension. If no such
    factory can be found, **Qt Designer** will use the default property sheet.

    There are four available types of extensions in **Qt Designer** :
    **QDesignerContainerExtension** , **QDesignerMemberSheetExtension** ,
    QDesignerPropertySheetExtension and **QDesignerTaskMenuExtension** . Qt
    Designer's behavior is the same whether the requested extension is
    associated with a multi page container, a member sheet, a property sheet or
    a task menu.

    The **QExtensionFactory**  class provides a standard extension factory, and
    can also be used as an interface for custom extension factories. You can
    either create a new **QExtensionFactory**  and reimplement the
    **QExtensionFactory::createExtension** () function. For example:

    **QObject**  *ANewExtensionFactory::createExtension(**QObject**  *object,
    const **QString**  &iid, **QObject**  *parent) const
        {
            if (iid
    != Q_TYPEID(QDesignerPropertySheetExtension))
                return 0;
    if (MyCustomWidget *widget = qobject_cast<MyCustomWidget*>
    (object))
                return new MyPropertySheetExtension(widget, parent);
    return 0;
        }

    Or you can use an existing factory, expanding the
    **QExtensionFactory::createExtension** () function to make the factory able
    to create a property sheet extension extension as well. For example:

    **QObject**  *AGeneralExtensionFactory::createExtension(**QObject**
    *object,
                const **QString**  &iid, **QObject**  *parent) const
    {
            MyCustomWidget *widget = qobject_cast<MyCustomWidget*>(object);
    if (widget && (iid == Q_TYPEID(**QDesignerTaskMenuExtension** ))) {
    return new MyTaskMenuExtension(widget, parent);

            } else if
    (widget && (iid == Q_TYPEID(QDesignerPropertySheetExtension))) {
    return new MyPropertySheetExtension(widget, parent);

            } else {
    return 0;
            }
        }

    For a complete example using an extension class, see the **Task Menu
    Extension example** . The example shows how to create a custom widget plugin
    for Qt Designer, and how to to use the **QDesignerTaskMenuExtension**  class
    to add custom items to **Qt Designer** 's task menu.

    **See also** **QDesignerDynamicPropertySheetExtension** ,
    **QExtensionFactory** , **QExtensionManager** , and **Creating Custom Widget
    Extensions** .
    """

    def __init__(self) -> None:
        ...

    def isEnabled(self, index: int) -> bool:
        """
        https://doc.qt.io/qt-6/qdesignerpropertysheetextension.html#isEnabled

        **[pure virtual, since 5.0] bool
        QDesignerPropertySheetExtension::isEnabled(int index ) const**

        Returns true if the property at the given **index** is enabled in **Qt
        Designer** 's property editor, otherwise false.

        This function was introduced in Qt 5.0.

        **See also** **indexOf** ().
        """
        ...

    def setChanged(self, index: int, changed: bool) -> None:
        """
        https://doc.qt.io/qt-6/qdesignerpropertysheetextension.html#setChanged

        **[pure virtual] void QDesignerPropertySheetExtension::setChanged(int
        index , bool changed )**

        Sets whether the property at the given **index** is different from its
        default value, or not, depending on the **changed** parameter.

        **See also** **indexOf** () and **isChanged** ().
        """
        ...

    def isChanged(self, index: int) -> bool:
        """
        https://doc.qt.io/qt-6/qdesignerpropertysheetextension.html#isChanged

        **[pure virtual] bool QDesignerPropertySheetExtension::isChanged(int
        index ) const**

        Returns true if the value of the property at the given **index** differs
        from the property's default value, otherwise false.

        **See also** **indexOf** (), **setChanged** (), and **reset** ().
        """
        ...

    def setProperty(self, index: int, value: typing.Any) -> None:
        """
        https://doc.qt.io/qt-6/qdesignerpropertysheetextension.html#setProperty

        **[pure virtual] void QDesignerPropertySheetExtension::setProperty(int
        index , const QVariant & value )**

        Sets the **value** of the property at the given **index**.

        **Warning:** If you change the value of a property using this function,
        the undo stack is not updated. To ensure that a property's value can be
        reverted using the undo stack, you must use the
        **QDesignerFormWindowCursorInterface::setProperty** () function, or its
        buddy **setWidgetProperty** (), instead.

        **See also** **indexOf** (), **property** (), and **propertyGroup** ().
        """
        ...

    def property(self, index: int) -> typing.Any:
        """
        https://doc.qt.io/qt-6/qdesignerpropertysheetextension.html#property

        **[pure virtual] QVariant QDesignerPropertySheetExtension::property(int
        index ) const**

        Returns the value of the property at the given **index**.

        **See also** **indexOf** (), **setProperty** (), and **propertyGroup**
        ().
        """
        ...

    def setAttribute(self, index: int, b: bool) -> None:
        """
        https://doc.qt.io/qt-6/qdesignerpropertysheetextension.html#setAttribute

        **[pure virtual] void QDesignerPropertySheetExtension::setAttribute(int
        index , bool attribute )**

        If **attribute** is true, the property at the given **index** is made an
        attribute which will be **excluded** from the UI file; otherwise it will
        be included.

        **See also** **indexOf** () and **isAttribute** ().
        """
        ...

    def isAttribute(self, index: int) -> bool:
        """
        https://doc.qt.io/qt-6/qdesignerpropertysheetextension.html#isAttribute

        **[pure virtual] bool QDesignerPropertySheetExtension::isAttribute(int
        index ) const**

        Returns true if the property at the given **index** is an attribute,
        which will be **excluded** from the UI file, otherwise false.

        **See also** **indexOf** () and **setAttribute** ().
        """
        ...

    def setVisible(self, index: int, b: bool) -> None:
        """
        https://doc.qt.io/qt-6/qdesignerpropertysheetextension.html#setVisible

        **[pure virtual] void QDesignerPropertySheetExtension::setVisible(int
        index , bool visible )**

        If **visible** is true, the property at the given **index** is visible
        in **Qt Designer** 's property editor; otherwise the property is hidden.

        **See also** **indexOf** () and **isVisible** ().
        """
        ...

    def isVisible(self, index: int) -> bool:
        """
        https://doc.qt.io/qt-6/qdesignerpropertysheetextension.html#isVisible

        **[pure virtual] bool QDesignerPropertySheetExtension::isVisible(int
        index ) const**

        Returns true if the property at the given **index** is visible in **Qt
        Designer** 's property editor, otherwise false.

        **See also** **indexOf** () and **setVisible** ().
        """
        ...

    def reset(self, index: int) -> bool:
        """
        https://doc.qt.io/qt-6/qdesignerpropertysheetextension.html#reset

        **[pure virtual] bool QDesignerPropertySheetExtension::reset(int index
        )**

        Resets the value of the property at the given **index** , to the default
        value. Returns true if a default value could be found, otherwise false.

        **See also** **indexOf** (), **hasReset** (), and **isChanged** ().
        """
        ...

    def hasReset(self, index: int) -> bool:
        """
        https://doc.qt.io/qt-6/qdesignerpropertysheetextension.html#hasReset

        **[pure virtual] bool QDesignerPropertySheetExtension::hasReset(int
        index ) const**

        Returns true if the property at the given **index** has a reset button
        in **Qt Designer** 's property editor, otherwise false.

        **See also** **indexOf** () and **reset** ().
        """
        ...

    def setPropertyGroup(self, index: int, group: str) -> None:
        """
        https://doc.qt.io/qt-6/qdesignerpropertysheetextension.html#setPropertyG
        roup

        **[pure virtual] void
        QDesignerPropertySheetExtension::setPropertyGroup(int index , const
        QString & group )**

        Sets the property group for the property at the given **index** to
        **group**.

        Relating a property to a group makes it appear within that group's
        section in the property editor. The default property group of any
        property is the name of the class that defines it. For example, the
        **QObject::objectName**  property appears within the **QObject**
        property group.

        **See also** **indexOf** (), **property** (), and **propertyGroup** ().
        """
        ...

    def propertyGroup(self, index: int) -> str:
        """
        https://doc.qt.io/qt-6/qdesignerpropertysheetextension.html#propertyGrou
        p

        **[pure virtual] QString
        QDesignerPropertySheetExtension::propertyGroup(int index ) const**

        Returns the property group for the property at the given **index**.

        **Qt Designer** 's property editor supports property groups, i.e.
        sections of related properties. A property can be related to a group
        using the **setPropertyGroup** () function. The default group of any
        property is the name of the class that defines it. For example, the
        **QObject::objectName**  property appears within the **QObject**
        property group.

        **See also** **indexOf** () and **setPropertyGroup** ().
        """
        ...

    def propertyName(self, index: int) -> str:
        """
        https://doc.qt.io/qt-6/qdesignerpropertysheetextension.html#propertyName

        **[pure virtual] QString
        QDesignerPropertySheetExtension::propertyName(int index ) const**

        Returns the name of the property at the given **index**.

        **See also** **indexOf** ().
        """
        ...

    def indexOf(self, name: str) -> int:
        """
        https://doc.qt.io/qt-6/qdesignerpropertysheetextension.html#indexOf

        **[pure virtual] int QDesignerPropertySheetExtension::indexOf(const
        QString & name ) const**

        Returns the index for a given property **name**.

        **See also** **propertyName** ().
        """
        ...

    def __len__(self) -> int:
        ...

    def count(self) -> int:
        """
        https://doc.qt.io/qt-6/qdesignerpropertysheetextension.html#count

        **[pure virtual] int QDesignerPropertySheetExtension::count() const**

        Returns the selected widget's number of properties.
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import typing
import PyQt6.sip
from PyQt6 import QtCore
from PyQt6.QtHelp import *


class QHelpContentModel(QtCore.QAbstractItemModel):
    """
    https://doc.qt.io/qt-6/qhelpcontentmodel.html

    **Detailed Description**
    """

    def isCreatingContents(self) -> bool:
        """
        https://doc.qt.io/qt-6/qhelpcontentmodel.html#isCreatingContents

        **bool QHelpContentModel::isCreatingContents() const**

        Returns true if the contents are currently rebuilt, otherwise false.
        """
        ...

    def columnCount(self, parent: QtCore.QModelIndex = ...) -> int:
        """
        https://doc.qt.io/qt-6/qhelpcontentmodel.html#columnCount

        **[override virtual] int QHelpContentModel::columnCount(const
        QModelIndex & parent = QModelIndex()) const**

        Reimplements: **QAbstractItemModel::columnCount(const QModelIndex
        &parent) const** .

        Returns the number of columns under the given **parent**. Currently
        returns always 1.
        """
        ...

    def rowCount(self, parent: QtCore.QModelIndex = ...) -> int:
        """
        https://doc.qt.io/qt-6/qhelpcontentmodel.html#rowCount

        **[override virtual] int QHelpContentModel::rowCount(const QModelIndex &
        parent = QModelIndex()) const**

        Reimplements: **QAbstractItemModel::rowCount(const QModelIndex &parent)
        const** .

        Returns the number of rows under the given **parent**.
        """
        ...

    def parent(self, index: QtCore.QModelIndex) -> QtCore.QModelIndex:
        """
        https://doc.qt.io/qt-6/qhelpcontentmodel.html#parent

        **[override virtual] QModelIndex QHelpContentModel::parent(const
        QModelIndex & index ) const**

        Reimplements: **QAbstractItemModel::parent(const QModelIndex &index)
        const** .

        Returns the parent of the model item with the given **index** , or
        QModelIndex() if it has no parent.
        """
        ...

    def index(
        self, row: int, column: int, parent: QtCore.QModelIndex = ...
    ) -> QtCore.QModelIndex:
        """
        https://doc.qt.io/qt-6/qhelpcontentmodel.html#index

        **[override virtual] QModelIndex QHelpContentModel::index(int row , int
        column , const QModelIndex & parent = QModelIndex()) const**

        Reimplements: **QAbstractItemModel::index(int row, int column, const
        QModelIndex &parent) const** .

        Returns the index of the item in the model specified by the given
        **row** , **column** and **parent** index.
        """
        ...

    def data(self, index: QtCore.QModelIndex, role: int) -> typing.Any:
        """
        https://doc.qt.io/qt-6/qhelpcontentmodel.html#data

        **[override virtual] QVariant QHelpContentModel::data(const QModelIndex
        & index , int role ) const**

        Reimplements: **QAbstractItemModel::data(const QModelIndex &index, int
        role) const** .

        Returns the data stored under the given **role** for the item referred
        to by the **index**.
        """
        ...

    def contentItemAt(self, index: QtCore.QModelIndex) -> QHelpContentItem:
        """
        https://doc.qt.io/qt-6/qhelpcontentmodel.html#contentItemAt

        **QHelpContentItem *QHelpContentModel::contentItemAt(const QModelIndex &
        index ) const**

        Returns the help content item at the model index position **index**.
        """
        ...

    def createContents(self, customFilterName: str) -> None:
        """
        https://doc.qt.io/qt-6/qhelpcontentmodel.html#createContents

        **void QHelpContentModel::createContents(const QString &
        customFilterName )**

        Creates new contents by querying the help system for contents specified
        for the **customFilterName**.
        """
        ...

    @property
    def contentsCreated(self) -> PyQt6.QtCore.pyqtBoundSignal:
        """
        https://doc.qt.io/qt-6/qhelpcontentmodel.html#contentsCreated

        **[signal] void QHelpContentModel::contentsCreated()**

        This signal is emitted when the contents have been created.
        """
        ...

    @property
    def contentsCreationStarted(self) -> PyQt6.QtCore.pyqtBoundSignal:
        """
        https://doc.qt.io/qt-6/qhelpcontentmodel.html#contentsCreationStarted

        **[signal] void QHelpContentModel::contentsCreationStarted()**

        This signal is emitted when the creation of the contents has started.
        The current contents are invalid from this point on until the signal
        **contentsCreated** () is emitted.

        **See also** **isCreatingContents** ().
        """
        ...
